@@ -1,18 +1,18 @@
 # Schedwi
-# Copyright (C) 2011 Herve Quatremain
-# 
+# Copyright (C) 2011-2013 Herve Quatremain
+#
 # This file is part of Schedwi.
-# 
+#
 # Schedwi is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
-# 
+#
 # Schedwi is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -126,7 +126,7 @@ Its format is one of the following:
 
 Not or ! at the beginning of the calendar string means `Every day except
 the ones defined by the following calendar string'
- 
+
 Full examples:
      1/Thur
            Every Thursday of January
@@ -161,23 +161,26 @@ import datetime
 import calendar
 import sys
 
+import locale_utils
 import colors
 
-(   CAL_MALLOC,       # Memory allocation error
-    CAL_NOERROR,      # Success
-    CAL_NOMATCH,      # The day doesn't match the calendar (calmatch)
-    CAL_BADMONTHNAME, # Unknown month name (must be Jan...Dec)
-    CAL_BADDAYNAME,   # Unknown day name (must be Sun...Sat)
-    CAL_MONTHOOR,     # Month number out of range (1...12)
-    CAL_DAYOOR,       # Day out of range (1...31)
-    CAL_BADOPTION,    # Unknown option (must be Last, first, -1, ...)
-    CAL_EMPTYFIELD    # A part is empty (1-6//Last)
+(CAL_MALLOC,        # Memory allocation error
+ CAL_NOERROR,       # Success
+ CAL_NOMATCH,       # The day doesn't match the calendar (calmatch)
+ CAL_BADMONTHNAME,  # Unknown month name (must be Jan...Dec)
+ CAL_BADDAYNAME,    # Unknown day name (must be Sun...Sat)
+ CAL_MONTHOOR,      # Month number out of range (1...12)
+ CAL_DAYOOR,        # Day out of range (1...31)
+ CAL_BADOPTION,     # Unknown option (must be Last, first, -1, ...)
+ CAL_EMPTYFIELD     # A part is empty (1-6//Last)
 ) = (-1, 0, -2, -3, -4, -5, -6, -7, -8)
 
+
 def is_leap_year(year):
     """Check if the provided year is a leap year."""
     return ((year % 4 == 0) and (year % 100)) or (year % 400 == 0)
 
+
 def get_last_day(year, month):
     """Return the last day number of the provided month and year.
 
@@ -203,6 +206,7 @@ def get_last_day(year, month):
         return 28
     return 30
 
+
 def day_of_week(day, month, year):
     """Compute and return the week day (0=Sunday, 1=Monday, ..., 6=Saturday)
 
@@ -217,7 +221,8 @@ def day_of_week(day, month, year):
         y = year
         m = 2
     return ((23 * month / 9) + day + 4 + year + (y / 4) \
-            - (y / 100) + (y / 400) - m) % 7 
+            - (y / 100) + (y / 400) - m) % 7
+
 
 def get_open_day(month, year, inc):
     """Return the day number in the provided month that is not a week-end day.
@@ -226,7 +231,7 @@ def get_open_day(month, year, inc):
     if inc > 0:
         inc -= 1
         mday = 1
-        wday = day_of_week (mday, month, year)
+        wday = day_of_week(mday, month, year)
         if wday == 0:
             wday = 1
             mday = 2
@@ -240,8 +245,8 @@ def get_open_day(month, year, inc):
         return mday + inc + nb_week * 2
     else:
         inc += 1
-        mday = get_last_day (year, month)
-        wday = day_of_week (mday, month, year)
+        mday = get_last_day(year, month)
+        wday = day_of_week(mday, month, year)
         if wday == 0:
             wday = 5
             mday -= 2
@@ -253,6 +258,7 @@ def get_open_day(month, year, inc):
             nb_week += 1
         return mday + inc - nb_week * 2
 
+
 def get_easter(year):
     """Return the month and day number of Easter for the given year.
 
@@ -267,31 +273,34 @@ def get_easter(year):
     e = b & 3
     f = (b + 8) / 25
     g = (b - f + 1) / 3
-    h = (19 * a + b -d -g + 15) % 30
+    h = (19 * a + b - d - g + 15) % 30
     i = c >> 2
     k = c & 3
-    l = (32 + (e << 1) + (i << 1) - h -k) % 7
+    l = (32 + (e << 1) + (i << 1) - h - k) % 7
     m = (a + 11 * h + 22 * l) / 451
     easter_month = (h + l - 7 * m + 114) / 31
     p = (h + l - 7 * m + 114) % 31
     easter_day = p + 1
     return (easter_month, easter_day)
 
+
 def get_paskha(year):
     """Return the number of days in the year for Paskha (Orthodox Easter)."""
-    a=year % 19
-    b=year %  4
-    c=year %  7
+    a = year % 19
+    b = year % 4
+    c = year % 7
     d = (19 * a + 15) % 30
     e = (2 * b + 4 * c + 6 * d + 6) % 7
     cumdays = 31 + 28
-    if is_leap_year (year):
+    if is_leap_year(year):
             cumdays += 1
     return cumdays + 22 + d + e + 13
 
+
 def is_bit_set(bit_field, val):
     return bit_field & (1 << (val - 1))
 
+
 def add_range(bit_field, min, max, length):
     if min <= 0:
         min = 1
@@ -300,24 +309,28 @@ def add_range(bit_field, min, max, length):
 
     if min > max:
         bit_field |= ~(~0 << max)
-        bit_field |= (~(~0 << (length - min + 1))) << (min -1)
+        bit_field |= (~(~0 << (length - min + 1))) << (min - 1)
     else:
-        bit_field |= (~(~0 << (max - min + 1))) << (min -1)
+        bit_field |= (~(~0 << (max - min + 1))) << (min - 1)
     return bit_field
 
+
 def add_range_week(user_data, min, max):
     user_data["day"] = add_range(user_data["day"], min, max, 7)
 
+
 def add_range_month(user_data, min, max):
     user_data.month = add_range(user_data.month, min, max, 31)
 
-def add_range_all_month (user_data, min, max):
+
+def add_range_all_month(user_data, min, max):
     for m in range(12):
         if is_bit_set(user_data.month, m + 1):
             i = convert_mday(min, user_data.cal_year, m + 1)
             j = convert_mday(max, user_data.cal_year, m + 1)
             user_data.year[m] = add_range(user_data.year[m], i, j, 31)
 
+
 def convert_mday(val, year, month):
     """Convert a negative value to a day number in the month (1-31).
 
@@ -328,12 +341,13 @@ def convert_mday(val, year, month):
     # If the value is positive, nothing has to be done
     if val > 0:
         return val
-    last_day = get_last_day (year, month)
+    last_day = get_last_day(year, month)
     ret = last_day + val + 1
     if ret <= 0:
         return last_day + 1
     return ret
 
+
 def get_month_number(month_name):
     """Convert a month name to a number (1 to 12).
 
@@ -367,22 +381,26 @@ def get_month_number(month_name):
         return 12
     return 0
 
-def parse_month (month_str):
+
+def parse_month(month_str):
     """Parse a month (1-12 or Jan-Dec).
 
-    Return the month number (between 1 and 12) or an error code (<0)
-
+    @return:
+            the tuple (error_code, month_number) with month_number the
+            month number (between 1 and 12). month_number is 0 if month_str
+            is invalid and the error_code is set.
     """
     try:
         m = int(month_str)
     except ValueError:
         ret = get_month_number(month_str.strip())
         if ret == 0:
-            return CAL_BADMONTHNAME
-        return ret
+            return (CAL_BADMONTHNAME, 0)
+        return (CAL_NOERROR, ret)
     if m < 1 or m > 12:
-        return CAL_MONTHOOR
-    return m
+        return (CAL_MONTHOOR, 0)
+    return (CAL_NOERROR, m)
+
 
 def get_day_number(day_name):
     """Convert a day name to a number (1 to 7).
@@ -407,17 +425,20 @@ def get_day_number(day_name):
         return 7
     return 0
 
+
 def parse_wday(day_str):
     """Parse a weekday name.
 
-    Return the weekday number (between 1 and 7 with 1 for Sunday) or
-    an error code (<0)
-
+    @return:
+            the tuple (error_code, weekday_number) with weekday_number the
+            weekday number (between 1 and 7 with 1 for Sunday).
+            weekday_number is 0 if day_str is invalid and error_code is set.
     """
     ret = get_day_number(day_str.strip())
     if ret == 0:
-        return CAL_BADDAYNAME
-    return ret
+        return (CAL_BADDAYNAME, 0)
+    return (CAL_NOERROR, ret)
+
 
 def parse_mday(day_str):
     """Convert the given `day_str' string to an integer.
@@ -426,17 +447,20 @@ def parse_mday(day_str):
     or 1 to 31.  A negative value is the number of days from the end of the
     month (ie. -1 for the last day of the month)
 
-    Return the integer corresponding to `day_str' (in the range 1 to 31 or
-    -1 to -31), or an error code (<0)
+    @return:
+            the tuple (error_code, value) with value an integer corresponding
+            to `day_str' (in the range 1 to 31 or -1 to -31). value is 0 in
+            case of error and the error_code is set.
 
     """
     try:
         d = int(day_str)
     except ValueError:
-        return CAL_DAYOOR
+        return (CAL_DAYOOR, 0)
     if d > 31 or d < -31 or d == 0:
-        return CAL_DAYOOR
-    return d
+        return (CAL_DAYOOR, 0)
+    return (CAL_NOERROR, d)
+
 
 def parse_inc(day_opt):
     """Parse an option string.
@@ -465,6 +489,7 @@ def parse_inc(day_opt):
     else:
         return val
 
+
 def parse_range(str, parse, set_range, user_data):
     """Parse a range.
 
@@ -475,7 +500,8 @@ def parse_range(str, parse, set_range, user_data):
                     month, it's the last day)
                *  : always match
        The provided parse function is used to parse both side of the range and
-       must return an integer (and 0 in case of error)
+       must return a tupe (error_code, integer) with integer set to 0 in case
+       of error.
        The provided set_range function is called to set a value. The first
        parameter is the provided user_data
        In case of parsing error (syntax error), the tuple (error_code,
@@ -493,24 +519,25 @@ def parse_range(str, parse, set_range, user_data):
     i = len(lst)
     if i == 1 or not lst[0]:
         # Single value
-        min = parse(lst[0] if i == 1 else '-' + lst[1])
-        if min <= 0:
-            return (min, str.index(lst[0] if i == 1 else '-' + lst[1]))
+        err, min = parse(lst[0] if i == 1 else '-' + lst[1])
+        if min == 0:
+            return (err, str.index(lst[0] if i == 1 else '-' + lst[1]))
         set_range(user_data, min, min)
         return (CAL_NOERROR, 0)
-    min = parse(lst[0].strip())
-    if min <= 0:
-        return (min, str.index(lst[0]))
+    err, min = parse(lst[0].strip())
+    if min == 0:
+        return (err, str.index(lst[0]))
     last = lst[1].strip()
     if not last:
         return (CAL_EMPTYFIELD, str.index('-'))
-    max = parse(last)
-    if max <= 0:
-        return (max, str.index(last))
+    err, max = parse(last)
+    if max == 0:
+        return (err, str.index(last))
     set_range(user_data, min, max)
     return (CAL_NOERROR, 0)
 
-def parse_list (str, parse, set_range, user_data):
+
+def parse_list(str, parse, set_range, user_data):
     """Split a list of values (2,4,5,6-10) and call parse_range for each of
        them.
 
@@ -554,7 +581,7 @@ class cal_t:
         if self.year[month - 1] == 0:
             self.month &= ~(1 << (month - 1))
 
-    def add_week (self, wday, year):
+    def add_week(self, wday, year):
         """Given a weekday bit field (wday), set this pattern to every week of
         the selected month of the year.
 
@@ -572,9 +599,9 @@ class cal_t:
                 self.year[m] |= days << (7 - dow)
                 self.year[m] |= wday >> dow
 
-    def add_one_week (self, wday, year, week):
+    def add_one_week(self, wday, year, week):
         """Add a week pattern to the selected month.
-        
+
         The week parameter tells which week to set (1, 2, 3, 4, 5 for the
         first, second, third, fourth and fifth week of the month or -1,
         -2, ... for the last, the one before the last, ... week of the month)
@@ -586,13 +613,13 @@ class cal_t:
                 continue
             # First, second, third, ...
             if week >= 0:
-                dow = day_of_week(1, m + 1, year) 
+                dow = day_of_week(1, m + 1, year)
                 d = (days >> dow) & 0x7F
                 self.year[m] |= d << (7 * (week - 1))
             # Last, one before last, ...
             else:
                 last = get_last_day(year, m + 1)
-                dow = day_of_week(last, m + 1, year) 
+                dow = day_of_week(last, m + 1, year)
                 d = (days >> (dow + 1)) & 0x7F
                 i = last + 7 * week
                 if i < 0:
@@ -600,7 +627,7 @@ class cal_t:
                 else:
                     self.year[m] |= d << i
 
-    def set_day_increment (self, year, month, day, increment):
+    def set_day_increment(self, year, month, day, increment):
         """Set a day plus an increment.
 
         increment is the number of days to add or remove (ie. +1 to add
@@ -613,7 +640,7 @@ class cal_t:
         if new_date.year == year:
             self.add_day(new_date.month, new_date.day)
 
-    def move_day (self, year, month, day, increment):
+    def move_day(self, year, month, day, increment):
         """Move a day.
 
         `increment' is the number of days to move the provided day
@@ -623,7 +650,7 @@ class cal_t:
         self.remove_day(month, day)
         self.set_day_increment(year, month, day, increment)
 
-    def move_week_day (self, year, wday, increment):
+    def move_week_day(self, year, wday, increment):
         """Move a week day."""
         for m in range(1, 13):
             if is_bit_set(self.month, m):
@@ -637,7 +664,7 @@ class cal_t:
                     else:
                         d += 1
 
-    def parse_and_move_week_day (self, year, day_str):
+    def parse_and_move_week_day(self, year, day_str):
         """Parse a week day and move it.
 
         Return the tuple (error_code, index_in_day_str).
@@ -665,10 +692,10 @@ class cal_t:
         except ValueError:
             return (CAL_EMPTYFIELD, j)
 
-        self.move_week_day (year, wday, incr)
+        self.move_week_day(year, wday, incr)
         return (CAL_NOERROR, 0)
 
-    def parse_option_day_move (self, year, str):
+    def parse_option_day_move(self, year, str):
         """Parse the option string used to move days if they fall on some
         week days.
 
@@ -680,7 +707,7 @@ class cal_t:
          with
             wday1 and wday2: weekday names to move
             +<nb> and -<nb>: number of day to move the weekday
-        
+
          For instance:
             Sat+2,Sun+1 --> Will move all the Saturdays and Sundays to Mondays
             Sat-1,Sun+1 --> Will move all the Saturdays to Fridays and the
@@ -691,7 +718,7 @@ class cal_t:
                             will move all the Saturdays to Sundays and then the
                             Sun-2 will move all the Sundays (included the
                             previously moved Saturdays) to Fridays
-        
+
          Return:
             CAL_NOERROR --> No error
             CAL_EMPTYFIELD --> No value to parse or missing value
@@ -718,7 +745,7 @@ class cal_t:
             incr = 0
         self.set_day_increment(year, month, day, incr)
 
-    def calcomp_paskha (self, date_str, year):
+    def calcomp_paskha(self, date_str, year):
         """Compute Paskha for the provided year.
 
         The string date_str is an increment from Paskha (ie. +1 for
@@ -729,14 +756,14 @@ class cal_t:
             incr = int(date_str)
         except ValueError:
             incr = 0
-        yday = get_paskha (year)
+        yday = get_paskha(year)
         d = datetime.date(year, 1, 1)
         delta = datetime.timedelta(yday - 1 + incr)
         new_date = d + delta
         if new_date.year == year:
             self.add_day(new_date.month, new_date.day)
 
-    def parse_option (self, day_opt, wday, year):
+    def parse_option(self, day_opt, wday, year):
         """Parse the option string.
 
         Return the tuple (error_code, idx_in_day_opt) with error_code:
@@ -765,7 +792,7 @@ class cal_t:
         while n < lstr and day_opt[n].isspace():
             n += 1
         if n == lstr:
-            d = { "day": 0 }
+            d = {"day": 0}
             add_range_week(d, 2, 6)
             wday = d["day"]
             self.add_week(wday, year)
@@ -780,7 +807,7 @@ class cal_t:
                     self.add_day(m + 1, ret)
         return (CAL_NOERROR, 0)
 
-    def calinvert (self):
+    def calinvert(self):
         """Invert the calendar."""
         for m in range(12):
             if is_bit_set(self.month, m + 1):
@@ -789,7 +816,7 @@ class cal_t:
                 self.month |= 1 << m
                 self.year[m] = ~0
 
-    def calmatch (self, day, month, year):
+    def calmatch(self, day, month, year):
         """Check that the provided date matches the calendar.
 
         Return:
@@ -803,7 +830,7 @@ class cal_t:
             return CAL_NOMATCH
         return CAL_NOERROR
 
-    def calcomp_month (self, month_str):
+    def calcomp_month(self, month_str):
         """Parse the month part.
 
         Example of month string:
@@ -811,7 +838,7 @@ class cal_t:
                        2: February
                      1-6: January to June (inclusive)
             feb-December: February to December
-                 1-4,dec: list of values (January to April and December) 
+                 1-4,dec: list of values (January to April and December)
 
         In case of parsing error (syntax error), the tuple (error_code,
         idx_in_str) is returned with idx_in_str the index of the error in
@@ -830,7 +857,7 @@ class cal_t:
             return (CAL_NOERROR, 0)
         return parse_list(month_str, parse_month, add_range_month, self)
 
-    def calcomp_day (self, day_str, day_opt, year):
+    def calcomp_day(self, day_str, day_opt, year):
         """Parse the day part and the optional modifier.
 
                      day_str: Day string to parse
@@ -846,7 +873,7 @@ class cal_t:
                          1: First day of the month
                       2-12: Second to 12th day of the month
                    Tue-Fri: Tuesday to Friday (included)
-                 1-4,21-25: list of values (1 to 4 and 21 to 25) 
+                 1-4,21-25: list of values (1 to 4 and 21 to 25)
                         -1: Last day of the month
                      20--2: From the 20th to the last but one day of the month
 
@@ -857,8 +884,8 @@ class cal_t:
 
         Example of day and option string:
                  mon/first: First monday of the month
-              mon-wed/last: Monday to Friday of the last week of the month 
-         Monday,sat/Second: Monday and Saturday of the second week of the month 
+              mon-wed/last: Monday to Friday of the last week of the month
+         Monday,sat/Second: Monday and Saturday of the second week of the month
 
         In case of parsing error (syntax error), the tuple (error_code,
         idx_in_str) is returned with idx_in_str the index of the error in
@@ -878,8 +905,10 @@ class cal_t:
         dlen = len(day_str)
         while n < dlen and day_str[n].isspace():
             n += 1
-        # Day number in the month: 1-31
-        if n != dlen and day_str[n].isdigit():
+        # Day number in the month: 1-31, -1, ...
+        if n != dlen and (day_str[n].isdigit() or (day_str[n] == '-' and
+                                                   n + 1 != dlen and
+                                                   day_str[n + 1].isdigit())):
             error, idx = parse_list(day_str[n:], parse_mday,
                                     add_range_all_month, self)
             if error != CAL_NOERROR:
@@ -894,13 +923,13 @@ class cal_t:
             error, idx = self.parse_option_day_move(year, day_opt[n:])
             return (error, n + idx)
         # Open
-        if day_str[n:n+4].lower() == "open":
+        if day_str[n:n + 4].lower() == "open":
             return self.parse_open_day(day_opt, year)
         # Day in the week: Mon-Sun or *
         if day_str[n] == '*':
-            d = { "day": ~0 }
+            d = {"day": ~0}
         else:
-            d = { "day": 0 }
+            d = {"day": 0}
             error, idx = parse_list(day_str[n:], parse_wday, add_range_week, d)
             if error != CAL_NOERROR:
                 return (error, n + idx)
@@ -911,7 +940,7 @@ class cal_t:
         while n < olen and day_opt[n].isspace():
             n += 1
         if n == olen:
-            self.add_week (day, year)
+            self.add_week(day, year)
             return (CAL_NOERROR, 0)
         error, idx = self.parse_option(day_opt[n:], day, year)
         return (error, n + idx)
@@ -923,10 +952,18 @@ class cal_t:
         """Print the calendar."""
         DAY_LEN = 3
         GUT_LEN = 4
+        loc = locale_utils.get_locale()
+        self.setfirstweekday(loc.first_week_day)
+        day_labels = list()
+        for i in range(loc.first_week_day, 7 + loc.first_week_day):
+            day_labels.append(
+                        loc.days['format']['abbreviated'][i % 7][:DAY_LEN])
+        str_day = ' '.join(day_labels).encode('utf-8')
         if month is not None:
-            t = "%s %d" % (calendar.month_name[month], self.cal_year)
+            t = "%s %d" % (loc.months['format']['wide'][month].encode('utf-8'),
+                           self.cal_year)
             print "%s" % t.center((DAY_LEN + 1) * 7)
-            print ' ' + calendar.weekheader(DAY_LEN)
+            print str_day
             for w in calendar.monthcalendar(self.cal_year, month):
                 for d in w:
                     if not d:
@@ -942,29 +979,33 @@ class cal_t:
                         sys.stdout.write("%3.d " % d)
                 print ""
         else:
-            c = calendar.Calendar()
-            ml= 1
-            mr= 2
-            print "%s" % str(self.cal_year).center((DAY_LEN + 1) * 14 + GUT_LEN)
+            c = calendar.Calendar(loc.first_week_day)
+            ml = 1
+            mr = 2
+            print "%s" % str(self.cal_year).center((DAY_LEN + 1) * 14 +
+                                                   GUT_LEN)
             for row in c.yeardayscalendar(self.cal_year, 2):
-                print "%s%s%s" % (
-                            calendar.month_name[ml].center((DAY_LEN + 1) * 7),
-                            " " * GUT_LEN,
-                            calendar.month_name[mr].center((DAY_LEN + 1) * 7))
-                print ' ' + calendar.weekheader(DAY_LEN) + \
-                      ' ' * GUT_LEN + calendar.weekheader(DAY_LEN)
+                str_ml = loc.months['format']['wide'][ml].encode('utf-8')
+                str_mr = loc.months['format']['wide'][mr].encode('utf-8')
+                print "%s%s%s" % (str_ml.center((DAY_LEN + 1) * 7),
+                                  " " * GUT_LEN,
+                                  str_mr.center((DAY_LEN + 1) * 7))
+                print str_day + ' ' * GUT_LEN + ' ' + str_day
                 for w in range(5):
                     if len(row[0]) > w:
                         for d in row[0][w]:
                             if not d:
                                 sys.stdout.write(" " * (DAY_LEN + 1))
                                 continue
-                            if self.calmatch(d, ml, self.cal_year)!=CAL_NOMATCH:
-                                sys.stdout.write(" " * (1 - self.highlight_len))
+                            if (self.calmatch(d, ml, self.cal_year) !=
+                                CAL_NOMATCH):
+                                sys.stdout.write(" " *
+                                                 (1 - self.highlight_len))
                                 sys.stdout.write(self.highlight_on)
                                 sys.stdout.write("%2.d" % d)
                                 sys.stdout.write(self.highlight_off)
-                                sys.stdout.write(" " * (1 - self.highlight_len))
+                                sys.stdout.write(" " *
+                                                 (1 - self.highlight_len))
                             else:
                                 sys.stdout.write("%3.d " % d)
                     else:
@@ -975,12 +1016,15 @@ class cal_t:
                             if not d:
                                 sys.stdout.write(" " * (DAY_LEN + 1))
                                 continue
-                            if self.calmatch(d, mr, self.cal_year)!=CAL_NOMATCH:
-                                sys.stdout.write(" " * (1 - self.highlight_len))
+                            if (self.calmatch(d, mr, self.cal_year) !=
+                                    CAL_NOMATCH):
+                                sys.stdout.write(" " *
+                                                 (1 - self.highlight_len))
                                 sys.stdout.write(self.highlight_on)
                                 sys.stdout.write("%2.d" % d)
                                 sys.stdout.write(self.highlight_off)
-                                sys.stdout.write(" " * (1 - self.highlight_len))
+                                sys.stdout.write(" " *
+                                                 (1 - self.highlight_len))
                             else:
                                 sys.stdout.write("%3.d " % d)
                     else:
@@ -990,7 +1034,8 @@ class cal_t:
                 ml += 2
                 mr += 2
 
-def calcomp (calendar, year):
+
+def calcomp(calendar, year):
     """Compile a calendar string into a form that is suitable for subsequent
     calendar checks.
 
@@ -1035,7 +1080,7 @@ def calcomp (calendar, year):
             invert_cal = True
             n += 1
         else:
-            if calendar[n:n+3].lower() == "not":
+            if calendar[n:n + 3].lower() == "not":
                 invert_cal = True
                 n += 3
             else:
@@ -1080,6 +1125,7 @@ def calcomp (calendar, year):
         cal.calinvert()
     return (CAL_NOERROR, 0, cal)
 
+
 def str2cal(calendar, year):
     """Compile a multiline calendar string into a form that is suitable for
     subsequent calendar checks.  The provided string may contains comments (on
@@ -1089,7 +1135,7 @@ def str2cal(calendar, year):
     calendar -- string to parse
     year -- year (used to compute Easter). Subsequent calendar checks must be
             in this year
-   
+
     Return a triplet (error_code, idx_in_str, new_cal)
 
     Example of calendar string:
@@ -1104,7 +1150,7 @@ def str2cal(calendar, year):
                       not easter: Every day except Easter
                12/25/Sat+2,Sun+1: Christmas.  If on a Saturday or Sunday, move
                                   to the following Monday
-   
+
     In case of parsing error (syntax error), the tuple (error_code, idx_in_str)
     is returned with idx_in_str the index of the error in calendar.
     Return code (first item in the tuple):
@@ -1140,4 +1186,3 @@ def str2cal(calendar, year):
         for m in range(12):
             cal.year[m] &= c.year[m]
     return (CAL_NOERROR, 0, cal)
-
