@@ -34,6 +34,9 @@ from tables.job_main import job_main
 from tables.job_command import job_command
 from tables.job_arguments import job_arguments
 from tables.job_loadenv import job_loadenv
+from tables.job_detach import job_detach
+from tables.job_manual import job_manual
+from tables.job_manual_command import job_manual_command
 from tables.job_file_out import job_file_out
 from tables.job_file_err import job_file_err
 from tables.job_control_group import job_control_group
@@ -62,6 +65,9 @@ from tables.job_retries_s import job_retries_s
 from tables.job_retries_interval_s import job_retries_interval_s
 from tables.job_start_limit_s import job_start_limit_s
 from tables.job_loadenv_s import job_loadenv_s
+from tables.job_detach_s import job_detach_s
+from tables.job_manual_s import job_manual_s
+from tables.job_manual_command_s import job_manual_command_s
 from tables.job_environment_s import job_environment_s
 from tables.constraint_file_s import constraint_file_s
 from tables.link_s import link_s
@@ -94,6 +100,9 @@ def usage():
                  Username * : hive
               Output file * : /dev/null
                Error file * : /dev/null
+                   Detach * : false
+                   Manual * : false
+     Alert cmd for manual * : cat "$SCHEDWI_TEMPLATE" | mail -s "waiting" root@localhost
       Linux Control Group * : schedwi
              Max duration * : No limit
         Number of retries * : 0
@@ -315,6 +324,34 @@ def cat(sql_session, current_cwd, arguments, workload=None):
             _print_val(_("Error file"), in_object, "%s", obj.file_err,
                     True if workload is None else job_main_s.rw_job_file_err)
 
+        in_object, obj = sql_hierarchy.get(sql_session, p,
+                          job_detach if workload is None else job_detach_s,
+                          workload)
+        if obj is not None:
+            _print_val(_("Detach"), in_object, "%s", bool(obj.detach),
+                       True if workload is None else job_main_s.rw_job_detach)
+
+        in_object, obj = sql_hierarchy.get(sql_session, p,
+                          job_manual if workload is None else job_manual_s,
+                          workload)
+        if obj is not None:
+            _print_val(_("Manual"), in_object, "%s", bool(obj.manual),
+                       True if workload is None else job_main_s.rw_job_manual)
+
+        in_object, obj = sql_hierarchy.get(sql_session, p,
+                          job_manual_command if workload is None
+                                             else job_manual_command_s,
+                          workload)
+        if obj is not None:
+            _print_val(_("Alert cmd for manual"), in_object, "%s",
+                       obj.manual_command,
+                       True if workload is None
+                            else job_main_s.rw_job_manual_command)
+        else:
+            _print_val(_("Alert cmd for manual"), True, "%s", _("None"),
+                       True if workload is None
+                            else job_main_s.rw_job_manual_command)
+
         in_object, obj = sql_hierarchy.get(sql_session, p,
                           job_control_group if workload is None \
                                             else job_control_group_s,
