@@ -63,6 +63,12 @@ from tables.job_arguments import job_arguments
 from tables.job_arguments_s import job_arguments_s
 from tables.job_loadenv import job_loadenv
 from tables.job_loadenv_s import job_loadenv_s
+from tables.job_detach import job_detach
+from tables.job_detach_s import job_detach_s
+from tables.job_manual import job_manual
+from tables.job_manual_s import job_manual_s
+from tables.job_manual_command import job_manual_command
+from tables.job_manual_command_s import job_manual_command_s
 from tables.job_stat import job_stat
 from tables.constraint_file import constraint_file
 from tables.constraint_file_s import constraint_file_s
@@ -94,6 +100,11 @@ Options:
   --user=PATTERN        search by the username under which the command is run.
   --stdout=PATTERN      search by the output file.
   --stderr=PATTERN      search by the error file.
+  --detach=True|False   search by whether the job must be run in detach mode,
+                        to start a daemon process for instance, or not.
+  --manual=True|False   search by whether a confirmation is asked before
+                        starting the job, or not.
+  --manual-cmd=PATTERN  search by the alert command for manual jobs.
   --cgroup=PATTERN      search by the Linux Control Group name.
   --duration=MINUTES    search by the maximum allowed duration.
                         0 means no limit.
@@ -364,6 +375,9 @@ def find(sql_session, current_cwd, arguments, workload=None):
                             "user=",
                             "stdout=",
                             "stderr=",
+                            "detach=",
+                            "manual=",
+                            "manual-cmd=",
                             "cgroup=",
                             "duration=",
                             "retries=",
@@ -628,6 +642,37 @@ Should be `H:M' or `H:M AM/PM'\n") % a)
                 query = query.filter(job_loadenv_s.job_id == job_main_s.id)
                 query = query.filter(job_loadenv_s.workload_date == workload)
 
+        elif o == "--detach":
+            if workload is None:
+                query = _filter_boolean(query, job_detach.detach, a)
+                query = query.filter(job_detach.job_id == job_main.id)
+            else:
+                query = _filter_boolean(query, job_detach_s.detach, a)
+                query = query.filter(job_detach_s.job_id == job_main_s.id)
+                query = query.filter(job_detach_s.workload_date == workload)
+
+        elif o == "--manual":
+            if workload is None:
+                query = _filter_boolean(query, job_manual.manual, a)
+                query = query.filter(job_manual.job_id == job_main.id)
+            else:
+                query = _filter_boolean(query, job_manual_s.manual, a)
+                query = query.filter(job_manual_s.job_id == job_main_s.id)
+                query = query.filter(job_manual_s.workload_date == workload)
+
+        elif o == "--manual-cmd":
+            if workload is None:
+                query = _filter_pattern(query,
+                                        job_manual_command.manual_command, a)
+                query = query.filter(job_manual_command.job_id == job_main.id)
+            else:
+                query = _filter_pattern(query,
+                                        job_manual_command_s.manual_command, a)
+                query = query.filter(job_manual_command_s.job_id ==
+                                        job_main_s.id)
+                query = query.filter(job_manual_command_s.workload_date ==
+                                        workload)
+
         elif o == "--has-env":
             if workload is None:
                 query = _filter_boolean(query, job_main.has_env, a)
