@@ -34,6 +34,9 @@ from tables.job_file_out import job_file_out
 from tables.job_file_err import job_file_err
 from tables.job_control_group import job_control_group
 from tables.job_loadenv import job_loadenv
+from tables.job_detach import job_detach
+from tables.job_manual import job_manual
+from tables.job_manual_command import job_manual_command
 from tables.job_success_return_code import job_success_return_code
 from tables.job_command import job_command
 from tables.job_arguments import job_arguments
@@ -83,6 +86,26 @@ Options:
   --stderr=FILE           command error file (stored on the Schedwi agent).
   --delstderr             use the file name defined in the parent
                           jobset instead.
+  --detach=True|False     start the job in detach mode (True) or not (False).
+                          In detach mode, Schedwi will not wait for the
+                          completion of the job but immediately set the status
+                          of the job on whether the job has successfully
+                          started or not. The detach mode can be useful to
+                          start daemons, services or long running processes.
+  --deldetach             use the value defined in the parent jobset instead.
+  --manual=True|False     ask confirmation (True) to operators to start the
+                          job or not (False).
+  --delmanual             use the value defined in the parent jobset instead.
+  --manual-cmd=COMMAND    for manual jobs, command/script to run to alert
+                          operators that a job is waiting for a start
+                          confirmation. The following environment variables
+                          are set and can be used in the command/script:
+                          SCHEDWI_TEMPLATE (the path to a text file that
+                          contains the message to send to operators),
+                          SCHEDWI_JOBPATH, SCHEDWI_JOBID, SCHEDWI_START_TIME,
+                          SCHEDWI_START_TIME_EPOCH, SCHEDWI_TIME_LIMIT and
+                          SCHEDWI_TIME_LIMIT_EPOCH.
+  --delmanual-cmd         use the value defined in the parent jobset instead.
   --cgroup=NAME           Linux Control Group name to set for the job.  This
                           name is relative to the controllers mount point.
                           For instance, for the /cgroup/cpu/schedwi/test mount
@@ -153,6 +176,12 @@ def parse_args(argv):
                 "delstdout",
                 "stderr=",
                 "delstderr",
+                "detach=",
+                "deldetach",
+                "manual=",
+                "delmanual",
+                "manual-cmd=",
+                "delmanual-cmd",
                 "cgroup=",
                 "delcgroup",
                 "duration=",
@@ -359,6 +388,27 @@ number of minutes for the job to be started past its start time \
         elif o == "--deluser-env":
             del job.job_loadenv
 
+        elif o == "--detach":
+            if a[0] in (_('Y'), _('y'), '1', _('t'), _('T')):
+                job.job_detach = job_detach(1)
+            else:
+                job.job_detach = job_detach(0)
+        elif o == "--deldetach":
+            del job.job_detach
+
+        elif o == "--manual":
+            if a[0] in (_('Y'), _('y'), '1', _('t'), _('T')):
+                job.job_manual = job_manual(1)
+            else:
+                job.job_manual = job_manual(0)
+        elif o == "--delmanual":
+            del job.job_manual
+
+        elif o == "--manual-cmd":
+            job.job_manual_command = job_manual_command(a)
+        elif o == "--delmanual-cmd":
+            del job.job_manual_command
+
         elif o == "--addenv":
             try:
                 env = environments_utils.name2env(session, a)
