@@ -83,6 +83,7 @@ import cmd_wl.start
 import cmd_wl.stop
 import cmd_wl.complete
 import cmd_wl.status
+import cmd_wl.trigger
 
 _history_file = "~/.schedwi_history"
 
@@ -215,6 +216,7 @@ stat      print job and jobset execution statistics
 stop      stop jobs and jobsets
 status    list job and jobset status
 tree      list contents of jobsets in a tree-like format
+trigger   trigger pending manual jobs and jobsets
 wl        list workload dates and change the current workload
 
 hosts     enter the hosts sub-command.  In this mode, the following commands
@@ -1069,6 +1071,33 @@ cal       enter the calendar sub-command.  In this mode, the following
         self.last_return_code = cmd_wl.status.status(self.sql_session, args,
                                                      self.workload)
 
+    def help_trigger(self):
+        cmd_wl.trigger.usage()
+
+    def complete_trigger(self, text, line, start_index, end_index):
+        """Readline argument completion"""
+        if self.context == JOB and self.workload is not None:
+            return cmd_job.complete.complete(self.sql_session, text, line,
+                            self.cwd_workload if self.workload else self.cwd,
+                            self.workload)
+        else:
+            return []
+
+    def do_trigger(self, s):
+        """Trigger pending manual jobs and jobsets"""
+        try:
+            args = self._my_shlex(s)
+        except:
+            self.last_return_code = 1
+            return self.last_return_code
+        if self.context == JOB:
+                self.last_return_code = cmd_wl.trigger.trigger(
+                                                        self.sql_session,
+                                                        self.cwd_workload,
+                                                        args, self.workload)
+        else:
+            self.default("trigger")
+
     def help_hosts(self):
         print _("""Usage: hosts [CMD]
 Enter the hosts sub-command.  If a hosts command is specified (CMD), it is
