@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2011, 2012 Herve Quatremain
+# Copyright (C) 2011-2013 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -172,10 +172,14 @@ def status(sql_session, arguments, workload):
             type_char = '/'
         else:
             type_char = ''
-        if options['print_message'] and j.error_msg:
-            message = _(" - %s - try %d") % (j.error_msg, j.retry_num)
-        else:
-            message = ''
+        message = ''
+        if options['print_message']:
+            if j.status == status_utils.WAITING:
+                reason = j.get_waiting_message()
+                if reason:
+                    message = " - %s" % reason
+            elif j.error_msg:
+                message = _(" - %s - try %d") % (j.error_msg, j.retry_num)
         if options['print_time']:
             date_time = time.strftime(options['time_format'],
                                       time.localtime(j.start_time)) + ' - '
