@@ -44,6 +44,8 @@ USER_ID = None
 GROUP_ID = None
 GUI_LOG_FILE = config.DEFAULT_GUI_LOG_FILE
 GUI_CONTEXT_ROOT = config.DEFAULT_GUI_CONTEXT_ROOT
+PAM_AUTH = config.DEFAULT_PAM_AUTH
+PAM_AUTH_SERVICE = config.DEFAULT_PAM_AUTH_SERVICE
 
 
 def _parse_file(f, conf_file_name):
@@ -51,7 +53,8 @@ def _parse_file(f, conf_file_name):
     global DBI_DRIVERNAME, DBI_DBNAME, DBI_USER, DBI_PASSWORD, \
            DBI_DBHOSTNAME, DBI_DBDIR, GUI_REFRESH, \
            GUI_USERNAME, GUI_PASSWORD, GUI_IFACE_LISTEN, GUI_PORT, \
-           USER_ID, GROUP_ID, GUI_LOG_FILE, GUI_CONTEXT_ROOT
+           USER_ID, GROUP_ID, GUI_LOG_FILE, GUI_CONTEXT_ROOT, \
+           PAM_AUTH_SERVICE, PAM_AUTH
     for line in f:
         m = re.search(r'^\s*DBI_DRIVERNAME\s*=\s*(.+)$', line)
         if m:
@@ -159,6 +162,18 @@ def _parse_file(f, conf_file_name):
                 sys.stderr.write("  ")
                 sys.stderr.write(_("Using the default path instead.\n"))
             continue
+        m = re.search(r'^\s*PAM_AUTH_SERVICE\s*=\s*(.+)$', line)
+        if m:
+            PAM_AUTH_SERVICE = m.group(1).rstrip()
+            continue
+        m = re.search(r'^\s*PAM_AUTH\s*=\s*(t|true|1|y|yes|on)', line, re.I)
+        if m:
+            PAM_AUTH = True
+            continue
+        m = re.search(r'^\s*PAM_AUTH\s*=\s*(f|false|0|n|no|off)', line, re.I)
+        if m:
+            PAM_AUTH = False
+            continue
 
 
 def parse(file=None):
