@@ -35,6 +35,19 @@ def status_list():
     return [WAITING, RUNNING, COMPLETED, FAILED, COMPLETED_OR_FAILED]
 
 
+def status2icon(st):
+    """Return the icon path for the given job/jobset state."""
+    if st == WAITING:
+        return 'icons/waiting.png'
+    elif st == RUNNING:
+        return 'icons/running.png'
+    elif st == COMPLETED:
+        return 'icons/completed.png'
+    elif st == FAILED:
+        return 'icons/failed.png'
+    return ''
+
+
 def status2string(st):
     """Convert a status number to a string."""
     if st == WAITING:
@@ -133,16 +146,29 @@ def get_status(sql_session, job_id, workload):
 
 
 def get_status_string(sql_session, job_id, workload):
-    """Return a string representing the status of the given job_id."""
-    status = get_status(sql_session, job_id, workload)
-    if not status:
-        return "waiting"
+    """Return a string representing the status of the given job/jobset.
+
+    @param sql_session:
+                SQLAlchemy session (it can be an opened session)
+    @param job_id:
+                the job ID to look for in the database.
+    @param workload:
+                workload to consider.
+    @return: the localized string representation of the status (with date)
+    """
+    job_status_obj = get_status(sql_session, job_id, workload)
+    if not job_status_obj:
+        return status2string(WAITING)
     time_str = babel.dates.format_time(
-                                datetime.fromtimestamp(status.start_time),
-                                format="short",
-                                locale=locale_utils.get_locale())
+                            datetime.fromtimestamp(job_status_obj.start_time),
+                            format="short", locale=locale_utils.get_locale())
+    reason = job_status_obj.get_waiting_message()
+    if reason:
+        return "%s (%s - %s)" % (status2string(job_status_obj.status),
+                                 time_str.encode('utf-8'), reason)
     return "%s (%s - try %d%s)" % (
-           status2string(status.status),
+           status2string(job_status_obj.status),
            time_str.encode('utf-8'),
-           status.retry_num,
-           (" - %s" % status.error_msg) if status.error_msg else '')
+           job_status_obj.retry_num,
+           (" - %s" % job_status_obj.error_msg) if job_status_obj.error_msg
+                                                else '')
