@@ -18,7 +18,7 @@
 
 from sqlalchemy.schema import Column
 from sqlalchemy.types import Integer, Text, String
-from sqlalchemy.orm import relation, backref
+from sqlalchemy.orm import relationship, backref
 
 from base import Base, convert2unicode
 
@@ -31,6 +31,9 @@ from job_file_out import job_file_out
 from job_file_err import job_file_err
 from job_control_group import job_control_group
 from job_loadenv import job_loadenv
+from job_detach import job_detach
+from job_manual import job_manual
+from job_manual_command import job_manual_command
 from job_success_return_code import job_success_return_code
 from job_command import job_command
 from job_arguments import job_arguments
@@ -56,64 +59,76 @@ class job_main(Base):
     cal_id = Column(Integer)
     start_time = Column(Integer)
 
-    job_start_limit = relation(job_start_limit,
+    job_start_limit = relationship(job_start_limit,
                                uselist=False,
                                backref="job_main",
                                cascade="all, delete, delete-orphan")
-    job_max_duration = relation(job_max_duration,
+    job_max_duration = relationship(job_max_duration,
                                 uselist=False,
                                 backref="job_main",
                                 cascade="all, delete, delete-orphan")
-    job_retries = relation(job_retries,
+    job_retries = relationship(job_retries,
                            uselist=False,
                            backref="job_main",
                            cascade="all, delete, delete-orphan")
-    job_retries_interval = relation(job_retries_interval,
+    job_retries_interval = relationship(job_retries_interval,
                                     uselist=False,
                                     backref="job_main",
                                     cascade="all, delete, delete-orphan")
-    job_username = relation(job_username,
+    job_username = relationship(job_username,
                             uselist=False,
                             backref="job_main",
                             cascade="all, delete, delete-orphan")
-    job_file_out = relation(job_file_out,
+    job_file_out = relationship(job_file_out,
                             uselist=False,
                             backref="job_main",
                             cascade="all, delete, delete-orphan")
-    job_file_err = relation(job_file_err,
+    job_file_err = relationship(job_file_err,
                             uselist=False,
                             backref="job_main",
                             cascade="all, delete, delete-orphan")
-    job_control_group = relation(job_control_group,
+    job_control_group = relationship(job_control_group,
                             uselist=False,
                             backref="job_main",
                             cascade="all, delete, delete-orphan")
-    job_loadenv = relation(job_loadenv, uselist=False, backref="job_main",
+    job_loadenv = relationship(job_loadenv, uselist=False, backref="job_main",
                            cascade="all, delete, delete-orphan")
-    job_success_return_code = relation(job_success_return_code,
+    job_detach = relationship(job_detach, uselist=False, backref="job_main",
+                           cascade="all, delete, delete-orphan")
+    job_manual = relationship(job_manual, uselist=False, backref="job_main",
+                           cascade="all, delete, delete-orphan")
+    job_manual_command = relationship(job_manual_command, uselist=False,
+                           backref="job_main",
+                           cascade="all, delete, delete-orphan")
+    job_success_return_code = relationship(job_success_return_code,
                                        uselist=False,
                                        backref="job_main",
                                        cascade="all, delete, delete-orphan")
-    job_command = relation(job_command,
+    job_command = relationship(job_command,
                            uselist=False,
                            backref="job_main",
                            cascade="all, delete, delete-orphan")
-    job_arguments = relation(job_arguments, order_by=job_arguments.position,
-                             backref="job_main",
-                             cascade="all, delete, delete-orphan")
-    job_environment = relation(job_environment,
+    job_arguments = relationship(job_arguments,
+                                 order_by=job_arguments.position,
+                                 backref="job_main",
+                                 cascade="all, delete, delete-orphan")
+    job_environment = relationship(job_environment,
                                order_by=job_environment.position,
                                backref="job_main",
                                cascade="all, delete, delete-orphan")
-    job_host = relation(job_host, uselist=False, backref="job_main",
+    job_host = relationship(job_host, uselist=False, backref="job_main",
                         cascade="all, delete, delete-orphan")
-    constraint_file = relation(constraint_file, order_by=constraint_file.exist,
-                               backref="job_main",
-                               cascade="all, delete, delete-orphan")
-    job_stat = relation(job_stat, uselist=False, backref="job_main",
-                        cascade="all, delete, delete-orphan")
-    links = relation(link, backref="job_main",
-                     primaryjoin=link.job_id_source == id,
+    constraint_file = relationship(constraint_file,
+                                   order_by=constraint_file.exist,
+                                   backref="job_main",
+                                   cascade="all, delete, delete-orphan")
+    job_stat = relationship(job_stat, uselist=False, backref="job_main",
+                            cascade="all, delete, delete-orphan")
+    links = relationship(link, backref="job_main",
+                         primaryjoin=link.job_id_source == id,
+                         cascade="all, delete, delete-orphan")
+    link_targets = relationship(link,
+                     primaryjoin=link.job_id_destination == id,
                      cascade="all, delete, delete-orphan")
 
     def __init__(self, parent, name, type, enabled, has_env,
@@ -169,6 +184,18 @@ class job_main(Base):
             j.job_loadenv = self.job_loadenv.copy()
         else:
             j.job_loadenv = self.job_loadenv
+        if self.job_detach:
+            j.job_detach = self.job_detach.copy()
+        else:
+            j.job_detach = self.job_detach
+        if self.job_manual:
+            j.job_manual = self.job_manual.copy()
+        else:
+            j.job_manual = self.job_manual
+        if self.job_manual_command:
+            j.job_manual_command = self.job_manual_command.copy()
+        else:
+            j.job_manual_command = self.job_manual_command
         if self.job_success_return_code:
             j.job_success_return_code = self.job_success_return_code.copy()
         else:
