@@ -18,7 +18,7 @@
 
 from sqlalchemy.schema import Column
 from sqlalchemy.types import Integer, Text, String
-from sqlalchemy.orm import relation, backref
+from sqlalchemy.orm import relationship, backref
 
 from base import Base, convert2unicode
 
@@ -31,6 +31,9 @@ from job_file_out_s import job_file_out_s
 from job_file_err_s import job_file_err_s
 from job_control_group_s import job_control_group_s
 from job_loadenv_s import job_loadenv_s
+from job_detach_s import job_detach_s
+from job_manual_s import job_manual_s
+from job_manual_command_s import job_manual_command_s
 from job_success_return_code_s import job_success_return_code_s
 from job_command_s import job_command_s
 from job_arguments_s import job_arguments_s
@@ -65,81 +68,98 @@ class job_main_s(Base):
     rw_start_time = True
     workload_date = Column(Integer, primary_key=True)
 
-    job_start_limit = relation(job_start_limit_s,
+    job_start_limit = relationship(job_start_limit_s,
                                uselist=False,
                                backref="job_main_s",
                                cascade="all, delete, delete-orphan")
     rw_job_start_limit = True
-    job_max_duration = relation(job_max_duration_s,
+    job_max_duration = relationship(job_max_duration_s,
                                 uselist=False,
                                 backref="job_main_s",
                                 cascade="all, delete, delete-orphan")
     rw_job_max_duration = True
-    job_retries = relation(job_retries_s,
+    job_retries = relationship(job_retries_s,
                            uselist=False,
                            backref="job_main_s",
                            cascade="all, delete, delete-orphan")
     rw_job_retries = True
-    job_retries_interval = relation(job_retries_interval_s,
+    job_retries_interval = relationship(job_retries_interval_s,
                                     uselist=False,
                                     backref="job_main_s",
                                     cascade="all, delete, delete-orphan")
     rw_job_retries_interval = True
-    job_username = relation(job_username_s,
+    job_username = relationship(job_username_s,
                             uselist=False,
                             backref="job_main_s",
                             cascade="all, delete, delete-orphan")
     rw_job_username = True
-    job_file_out = relation(job_file_out_s,
+    job_file_out = relationship(job_file_out_s,
                             uselist=False,
                             backref="job_main_s",
                             cascade="all, delete, delete-orphan")
     rw_job_file_out = True
-    job_file_err = relation(job_file_err_s,
+    job_file_err = relationship(job_file_err_s,
                             uselist=False,
                             backref="job_main_s",
                             cascade="all, delete, delete-orphan")
     rw_job_file_err = True
-    job_control_group = relation(job_control_group_s,
+    job_control_group = relationship(job_control_group_s,
                             uselist=False,
                             backref="job_main_s",
                             cascade="all, delete, delete-orphan")
     rw_job_control_group = True
-    job_loadenv = relation(job_loadenv_s, uselist=False, backref="job_main_s",
-                           cascade="all, delete, delete-orphan")
+    job_loadenv = relationship(job_loadenv_s, uselist=False,
+                               backref="job_main_s",
+                               cascade="all, delete, delete-orphan")
     rw_job_loadenv = True
-    job_success_return_code = relation(job_success_return_code_s,
+    job_detach = relationship(job_detach_s, uselist=False,
+                               backref="job_main_s",
+                               cascade="all, delete, delete-orphan")
+    rw_job_detach = True
+    job_manual = relationship(job_manual_s, uselist=False,
+                               backref="job_main_s",
+                               cascade="all, delete, delete-orphan")
+    rw_job_manual = True
+    job_manual_command = relationship(job_manual_command_s, uselist=False,
+                               backref="job_main_s",
+                               cascade="all, delete, delete-orphan")
+    rw_job_manual_command = True
+    job_success_return_code = relationship(job_success_return_code_s,
                                        uselist=False,
                                        backref="job_main_s",
                                        cascade="all, delete, delete-orphan")
     rw_job_success_return_code = True
-    job_command = relation(job_command_s,
+    job_command = relationship(job_command_s,
                            uselist=False,
                            backref="job_main_s",
                            cascade="all, delete, delete-orphan")
     rw_job_command = True
-    job_arguments = relation(job_arguments_s,
+    job_arguments = relationship(job_arguments_s,
                              order_by=job_arguments_s.position,
                              backref="job_main_s",
                              cascade="all, delete, delete-orphan")
     rw_job_arguments = True
-    job_environment = relation(job_environment_s,
+    job_environment = relationship(job_environment_s,
                                order_by=job_environment_s.position,
                                backref="job_main_s",
                                cascade="all, delete, delete-orphan")
     rw_job_environment = True
-    job_host = relation(job_host_s, uselist=False, backref="job_main_s",
+    job_host = relationship(job_host_s, uselist=False, backref="job_main_s",
                         cascade="all, delete, delete-orphan")
     rw_job_host = True
-    constraint_file = relation(constraint_file_s,
+    constraint_file = relationship(constraint_file_s,
                                order_by=constraint_file_s.exist,
                                backref="job_main_s",
                                cascade="all, delete, delete-orphan")
     rw_constraint_file = True
-    links = relation(link_s, backref="job_main_s",
+    links = relationship(link_s, backref="job_main_s",
                      primaryjoin=link_s.job_id_source == id,
                      cascade="all, delete, delete-orphan")
     rw_links = False
+    link_targets = relationship(link_s,
+                     primaryjoin=link_s.job_id_destination == id,
+                     cascade="all, delete, delete-orphan")
+    rw_link_targets = False
 
     def __init__(self, parent, name, type, enabled, has_env,
                  description, x, y, cal_id, start_time, workload_date):
@@ -195,6 +215,18 @@ class job_main_s(Base):
             j.job_loadenv = self.job_loadenv.copy()
         else:
             j.job_loadenv = self.job_loadenv
+        if self.job_detach:
+            j.job_detach = self.job_detach.copy()
+        else:
+            j.job_detach = self.job_detach
+        if self.job_manual:
+            j.job_manual = self.job_manual.copy()
+        else:
+            j.job_manual = self.job_manual
+        if self.job_manual_command:
+            j.job_manual_command = self.job_manual_command.copy()
+        else:
+            j.job_manual_command = self.job_manual_command
         if self.job_success_return_code:
             j.job_success_return_code = self.job_success_return_code.copy()
         else:
