@@ -54,6 +54,8 @@ from tables.job_file_out import job_file_out
 from tables.job_file_out_s import job_file_out_s
 from tables.job_username import job_username
 from tables.job_username_s import job_username_s
+from tables.job_manual_command import job_manual_command
+from tables.job_manual_command_s import job_manual_command_s
 import web.jobwindow
 from web.hostwindow import HostWindow
 from web.envwindow import EnvWindow
@@ -223,7 +225,7 @@ class Find(HorizontalLayout, IClickListener):
                     label=_("Job command") if job.type
                                            else _("Jobset command"),
                     obj_name=unicode(path.id2path(session, j.job_id,
-                                     self._workload)),
+                                                  self._workload)),
                     obj_type=self._JOB,
                     obj_id=j.job_id,
                     attr=web.jobwindow.FOCUS_CMD,
@@ -237,6 +239,31 @@ class Find(HorizontalLayout, IClickListener):
                     obj_type=self._NONE,
                     obj_id=0,
                     attr=web.jobwindow.FOCUS_CMD)
+            # job_manual_command
+            q = session.query(job_manual_command).filter(
+                              job_manual_command.manual_command.ilike(tofind))
+            i = 0
+            for j in q.limit(self._LIMIT):
+                job = simple_queries_job.sql_get_job(session, j.job_id,
+                                                     self._workload)
+                self._add_result(
+                    container=c,
+                    label=_("Alert command"),
+                    obj_name=unicode(path.id2path(session, j.job_id,
+                                                  self._workload)),
+                    obj_type=self._JOB,
+                    obj_id=j.job_id,
+                    attr=web.jobwindow.FOCUS_MANUALCMD,
+                    value=j.manual_command)
+                i += 1
+            if i >= self._LIMIT:
+                self._add_result(
+                    container=c,
+                    label=_("..."),
+                    obj_name=_("more job/jobset alert commands"),
+                    obj_type=self._NONE,
+                    obj_id=0,
+                    attr=web.jobwindow.FOCUS_MANUALCMD)
             # job_arguments
             q = session.query(job_arguments).filter(
                                         job_arguments.argument.ilike(tofind))
@@ -586,7 +613,7 @@ class Find(HorizontalLayout, IClickListener):
                     label=_("Job command") if job.type
                                            else _("Jobset command"),
                     obj_name=unicode(path.id2path(session, j.job_id,
-                                     self._workload)),
+                                                  self._workload)),
                     obj_type=self._JOB,
                     obj_id=j.job_id,
                     attr=web.jobwindow.FOCUS_CMD,
@@ -600,6 +627,32 @@ class Find(HorizontalLayout, IClickListener):
                     obj_type=self._NONE,
                     obj_id=0,
                     attr=web.jobwindow.FOCUS_CMD)
+            # job_manual_command
+            q = session.query(job_manual_command_s).filter(
+                             job_manual_command_s.manual_command.ilike(tofind))
+            q = q.filter(job_manual_command_s.workload_date == self._workload)
+            i = 0
+            for j in q.limit(self._LIMIT):
+                job = simple_queries_job.sql_get_job(session, j.job_id,
+                                                     self._workload)
+                self._add_result(
+                    container=c,
+                    label=_("Alert command"),
+                    obj_name=unicode(path.id2path(session, j.job_id,
+                                                  self._workload)),
+                    obj_type=self._JOB,
+                    obj_id=j.job_id,
+                    attr=web.jobwindow.FOCUS_MANUALCMD,
+                    value=j.manual_command)
+                i += 1
+            if i >= self._LIMIT:
+                self._add_result(
+                    container=c,
+                    label=_("..."),
+                    obj_name=_("more job/jobset alert commands"),
+                    obj_type=self._NONE,
+                    obj_id=0,
+                    attr=web.jobwindow.FOCUS_MANUALCMD)
             # job_arguments
             q = session.query(job_arguments_s).filter(
                                         job_arguments_s.argument.ilike(tofind))
