@@ -21,10 +21,10 @@
 from muntjac.api import Panel, Tree, HorizontalLayout, NativeButton, Alignment
 from muntjac.data.util.hierarchical_container import HierarchicalContainer
 from muntjac.data.property import IValueChangeListener
-from muntjac.ui.tree import (IExpandListener, ICollapseListener,
-                             IItemStyleGenerator)
+from muntjac.ui.tree import IExpandListener, ICollapseListener
 from muntjac.ui.button import IClickListener
 from muntjac.ui.abstract_select import ItemDescriptionGenerator
+from muntjac.terminal.theme_resource import ThemeResource
 
 from simple_queries_job import (sql_get_children, sql_count_children,
                                 sql_count_children2, sql_get_job)
@@ -41,6 +41,16 @@ class JobsetTree(Panel, CutCopyPasteMenuListener,
     """Jobset tree UI."""
 
     _ROOT_JOBSET_ID = 1
+    _ICON_STATUS = {
+        status_utils.WAITING:
+            ThemeResource(status_utils.status2icon(status_utils.WAITING)),
+        status_utils.RUNNING:
+            ThemeResource(status_utils.status2icon(status_utils.RUNNING)),
+        status_utils.COMPLETED:
+            ThemeResource(status_utils.status2icon(status_utils.COMPLETED)),
+        status_utils.FAILED:
+            ThemeResource(status_utils.status2icon(status_utils.FAILED))
+        }
 
     def __init__(self, application, sql_session, workload=None):
         """Create the UI.
@@ -69,13 +79,13 @@ class JobsetTree(Panel, CutCopyPasteMenuListener,
         self._tree.setNullSelectionAllowed(False)
         self._tree.setItemDescriptionGenerator(Tooltips(sql_session, workload))
         self._tree.addStyleName("jobsettree")
-        if workload is not None:
-            self._tree.setItemStyleGenerator(TreeStyleGenerator(self))
         self.addComponent(self._tree)
 
         # Container
         self._tree.setContainerDataSource(self._new_container())
         self._tree.setItemCaptionPropertyId('name')
+        if self._workload is not None:
+            self._tree.setItemIconPropertyId('icon')
 
         # Callbacks
         self._tree.addListener(self, IValueChangeListener)
@@ -112,9 +122,17 @@ class JobsetTree(Panel, CutCopyPasteMenuListener,
         """
         c = HierarchicalContainer()
         c.addContainerProperty('name', str, None)
+        if self._workload is not None:
+            c.addContainerProperty('icon', ThemeResource, None)
         # Root jobset
         item = c.addItem(self._ROOT_JOBSET_ID)
         item.getItemProperty('name').setValue('/')
+        if self._workload is not None:
+            status = status_utils.get_status(self._sql_session,
+                                             self._ROOT_JOBSET_ID,
+                                             self._workload)
+            item.getItemProperty('icon').setValue(
+                                            self._ICON_STATUS[status.status])
         return c
 
     def add_listener(self, obj):
@@ -189,6 +207,11 @@ class JobsetTree(Panel, CutCopyPasteMenuListener,
             child_id = child.id
             item = c.addItem(child_id)
             item.getItemProperty('name').setValue(child.name.encode('utf-8'))
+            if self._workload is not None:
+                status = status_utils.get_status(session, child_id,
+                                                 self._workload)
+                item.getItemProperty('icon').setValue(
+                                            self._ICON_STATUS[status.status])
             c.setParent(child_id, jobset_id)
             # Only show the expand arrow if the jobset has children
             if sql_count_children(session, child_id, True, self._workload):
@@ -458,22 +481,3 @@ class Tooltips(ItemDescriptionGenerator):
         else:
             s += '<br/>' + _("%d jobsets") % nb_jobsets
         return s
-
-
-class TreeStyleGenerator(IItemStyleGenerator):
-
-    """IItemStyleGenerator object to style the tree which the jobset status."""
-
-    def __init__(self, c):
-        """Initialize the object.
-
-        @param c:
-                    The L{JobsetTree} object.
-        """
-        self._c = c
-
-    def getStyle(self, itemId):
-        s = status_utils.get_status(self._c._sql_session, itemId,
-                                    self._c._workload)
-        if s:
-            return status_utils.status2colorname(s.status)
