@@ -18,15 +18,17 @@
 
 """Job list table UI."""
 
+import time
 from sqlalchemy import desc
 
 from muntjac.ui.embedded import Embedded
 from muntjac.api import (Table, VerticalLayout, HorizontalLayout, Label,
-                         NativeButton, Alignment)
+                         NativeButton, Alignment, ProgressIndicator)
 from muntjac.data.util.indexed_container import IndexedContainer
 from muntjac.data.property import IValueChangeListener
-from muntjac.ui.table import IHeaderClickListener, ICellStyleGenerator
+from muntjac.ui.table import IHeaderClickListener
 from muntjac.ui.button import IClickListener
+from muntjac.ui.window import Notification
 from muntjac.terminal.theme_resource import ThemeResource
 from muntjac.event.item_click_event import IItemClickListener
 
@@ -41,6 +43,9 @@ from web.cutcopypastemenu import (CutCopyPasteMenuJobTable, DeleteShortcut,
                                   CutCopyPasteMenuListener)
 from web.autorefresh import AutoRefresh
 import status_utils
+from simple_queries_stat import sql_get_stat_ratio_completion
+from simple_queries_ack import (sql_get_acknowledge_request_by_job_id,
+                                sql_update_acknowledge_request)
 
 
 class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
@@ -52,6 +57,16 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
     _ICON_JOB = ThemeResource('icons/job.png')
     _ICON_JOBSET = ThemeResource('icons/jobset.png')
     _ICON_ENABLED = ThemeResource('icons/check.png')
+    _ICON_STATUS = {
+        status_utils.WAITING:
+            ThemeResource(status_utils.status2icon(status_utils.WAITING)),
+        status_utils.RUNNING:
+            ThemeResource(status_utils.status2icon(status_utils.RUNNING)),
+        status_utils.COMPLETED:
+            ThemeResource(status_utils.status2icon(status_utils.COMPLETED)),
+        status_utils.FAILED:
+            ThemeResource(status_utils.status2icon(status_utils.FAILED))
+        }
 
     def __init__(self, sql_session, workload=None):
         """Create the UI.
@@ -172,6 +187,15 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
             btbox.addComponent(b)
             self._btstop = b
 
+            b = NativeButton()
+            b.setIcon(ThemeResource('icons/trigger.png'))
+            b.setDescription(_("Trigger manual start"))
+            b.setStyleName('toolbutton')
+            b.setEnabled(False)
+            b.addListener(TriggerBtHandler(self), IClickListener)
+            btbox.addComponent(b)
+            self._bttrigger = b
+
         # Job/jobset table
         self._table = Table()
         self._table.setSizeFull()
@@ -188,11 +212,24 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
         self._table.setContainerDataSource(self._new_container())
 
         # Columns
-        self._table.setVisibleColumns(['type', 'name', 'enabled', 'host',
-                                       'calendar', 'start'])
-        self._table.setColumnHeaders([_('Type'), _('Name'), _('Enabled'),
-                                      _('Host'),
+        if workload is None:
+            self._table.setVisibleColumns(['type', 'name',
+                                       'enabled', 'host', 'calendar', 'start'])
+            self._table.setColumnHeaders([_('Type'), _('Name'),
+                                      _('Enabled'), _('Host'),
                                       _('Calendar'), _('Start Time')])
+        else:
+            self._table.setVisibleColumns(['type', 'status', 'name',
+                                       'progress',
+                                       'enabled', 'host', 'calendar', 'start',
+                                       'message'])
+            self._table.setColumnHeaders([_('Type'), _("Status"), _('Name'),
+                                      _("Progress"),
+                                      _('Enabled'), _('Host'),
+                                      _('Calendar'), _('Start Time'),
+                                      _("Message")])
+            self._table.setColumnWidth('status', 45)
+            self._table.setColumnAlignment('status', Table.ALIGN_CENTER)
         self._table.setColumnWidth('type', 30)
         self._table.setColumnAlignment('type', Table.ALIGN_CENTER)
         self._table.setColumnWidth('enabled', 45)
@@ -207,8 +244,6 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
         if workload is None:
             # Keyboard shortcuts
             self._table.addShortcutListener(DeleteShortcut(self))
-        else:
-            self._table.setCellStyleGenerator(TableStyleGenerator(self))
 
     def _new_container(self):
         """Create and return a new container data source.
@@ -226,6 +261,11 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
         jContainer.addContainerProperty('start', str, None)
         # type_job: 0 --> jobset  and   1 --> job
         jContainer.addContainerProperty('type_job', int, None)
+        if self._workload is not None:
+            jContainer.addContainerProperty('status', Embedded, None)
+            jContainer.addContainerProperty('message', str, None)
+            jContainer.addContainerProperty('progress', ProgressIndicator,
+                                            None)
         return jContainer
 
     def add_listener(self, obj):
@@ -272,7 +312,8 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
                 self._btcut.setEnabled(True)
                 self._btcopy.setEnabled(True)
             else:
-                s = status_utils.get_status(self._sql_session, self._selected,
+                session = self._sql_session.open_session()
+                s = status_utils.get_status(session, self._selected,
                                             self._workload)
                 if s.status != status_utils.RUNNING:
                     self._btstart.setEnabled(True)
@@ -280,6 +321,21 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
                 else:
                     self._btstart.setEnabled(False)
                     self._btstop.setEnabled(True)
+                if s.status == status_utils.WAITING:
+                    try:
+                        ack = sql_get_acknowledge_request_by_job_id(session,
+                                                                self._selected,
+                                                                self._workload)
+                    except:
+                        self._bttrigger.setEnabled(False)
+                    else:
+                        if ack.status == 0:
+                            self._bttrigger.setEnabled(True)
+                        else:
+                            self._bttrigger.setEnabled(False)
+                else:
+                    self._bttrigger.setEnabled(False)
+                self._sql_session.close_session(session)
         else:
             self._btedit.setEnabled(False)
             if self._workload is None:
@@ -289,6 +345,7 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
             else:
                 self._btstart.setEnabled(False)
                 self._btstop.setEnabled(False)
+                self._bttrigger.setEnabled(False)
         if self._workload is None:
             if self._popup_menu.is_cut_or_copy():
                 self._btpaste.setEnabled(True)
@@ -423,20 +480,48 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
                 item.getItemProperty('calendar').setValue(
                                                 unicode(s).encode('utf-8'))
             # Start time
-            if job.start_time < 0:
-                # Retrieve the start time from a parent jobset (inherited)
-                in_object, obj = sql_hierarchy.get_start_time_id(session,
+            hour_str = None
+            if self._workload is not None:
+                status = status_utils.get_status(session, job.id,
+                                                 self._workload)
+                if status.status != status_utils.WAITING:
+                    if status.error_msg:
+                        item.getItemProperty('message').setValue(
+                                            status.error_msg.encode('utf-8'))
+                    # Display the status change time
+                    st = time.localtime(status.start_time)
+                    hour_str = "%02dh%02d" % (st.tm_hour, st.tm_min)
+                else:
+                    item.getItemProperty('message').setValue(
+                                status.get_waiting_message().encode('utf-8'))
+                e = Embedded(source=self._ICON_STATUS[status.status])
+                e.setDescription(status_utils.status2string(status.status))
+                item.getItemProperty('status').setValue(e)
+            if hour_str is None:
+                if job.start_time < 0:
+                    # Retrieve the start time from a parent jobset (inherited)
+                    in_object, obj = sql_hierarchy.get_start_time_id(session,
                                                                jobset_ids,
                                                                self._workload)
-                if obj is not None:
-                    start_time = obj.start_time
-                    s = "%02dh%02d" % (start_time / 100, start_time % 100)
-                    item.getItemProperty('start').setValue(s)
+                    if obj is not None:
+                        start_time = obj.start_time
+                        hour_str = "%02dh%02d" % (start_time / 100,
+                                                  start_time % 100)
+                    else:
+                        hour_str = '00h00'
                 else:
-                    item.getItemProperty('start').setValue('00h00')
-            else:
-                s = "%02dh%02d" % (job.start_time / 100, job.start_time % 100)
-                item.getItemProperty('start').setValue(s)
+                    hour_str = "%02dh%02d" % (job.start_time / 100,
+                                              job.start_time % 100)
+            item.getItemProperty('start').setValue(hour_str)
+            # Progress status
+            if self._workload is not None:
+                r = sql_get_stat_ratio_completion(session, job.id,
+                                                  self._workload)
+                if r is not None:
+                    p = ProgressIndicator(r)
+                    p.setWidth('100%')
+                    p.setPollingInterval(1000000000)  # No polling
+                    item.getItemProperty('progress').setValue(p)
         self._sql_session.close_session(session)
 
         # Only ask the container to sort `text' columns.  The other columns
@@ -448,8 +533,15 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
         self._table.setContainerDataSource(c)
         if selection in c.getItemIds():
             self._table.select(selection)
-        self._table.setVisibleColumns(['type', 'name', 'enabled', 'host',
-                                       'calendar', 'start'])
+        if self._workload is None:
+            self._table.setVisibleColumns(['type', 'name',
+                                           'enabled', 'host',
+                                           'calendar', 'start'])
+        else:
+            self._table.setVisibleColumns(['type', 'status', 'name',
+                                           'progress',
+                                           'enabled', 'host',
+                                           'calendar', 'start', 'message'])
         self.toolbar_set_state()
 
     def get_jobset_ids(self):
@@ -720,6 +812,42 @@ class StopBtHandler(IClickListener):
         self._c._popup_menu.do_stop(self._c.get_selected())
 
 
+class TriggerBtHandler(IClickListener):
+
+    """Callback for the Trigger start manual job button."""
+
+    def __init__(self, job_table_obj):
+        """Initialize the callback.
+
+        @param job_table_obj:
+                    the associated L{JobTable} object.
+        @type job_table_obj:    L{JobTable}
+        """
+        super(TriggerBtHandler, self).__init__()
+        self._c = job_table_obj
+
+    def buttonClick(self, event):
+        AutoRefresh.reset()
+        try:
+            sql_update_acknowledge_request(self._c._sql_session,
+                                           self._c.get_selected(),
+                                           self._c._workload)
+        except:
+            self._c.getWindow().showNotification(
+                    _("Internal error."),
+                    _("<br/>Job/jobset (%d_%d) not found in the database.") %
+                        (self._c.workload_date, self._c.get_selected()),
+                    Notification.TYPE_ERROR_MESSAGE)
+        else:
+            n = Notification(
+                    _("Acknowledgement taken into account."),
+                    _("<br/>This may take up to a minute to be taken into \
+                       account."),
+                    Notification.TYPE_WARNING_MESSAGE)
+            n.setDelayMsec(5000)
+            self._c.getWindow().showNotification(n)
+
+
 class DoubleClick(IItemClickListener):
 
     """Double-click callback."""
@@ -745,23 +873,3 @@ class DoubleClick(IItemClickListener):
             else:
                 self._c._popup_menu.do_edit(item_id,
                                     event.getClientX(), event.getClientY())
-
-
-class TableStyleGenerator(ICellStyleGenerator):
-
-    """ICellStyleGenerator object to style the rows which the job status."""
-
-    def __init__(self, c):
-        """Initialize the object.
-
-        @param c:
-                    The L{JobTable} object.
-        """
-        self._c = c
-
-    def getStyle(self, itemId, propertyId):
-        if propertyId == "name":
-            s = status_utils.get_status(self._c._sql_session, itemId,
-                                        self._c._workload)
-            if s:
-                return status_utils.status2colorname(s.status)
