@@ -48,6 +48,12 @@ from tables.job_control_group import job_control_group
 from tables.job_control_group_s import job_control_group_s
 from tables.job_loadenv import job_loadenv
 from tables.job_loadenv_s import job_loadenv_s
+from tables.job_detach import job_detach
+from tables.job_detach_s import job_detach_s
+from tables.job_manual import job_manual
+from tables.job_manual_s import job_manual_s
+from tables.job_manual_command import job_manual_command
+from tables.job_manual_command_s import job_manual_command_s
 from web.selecthostwidget import SelectHost
 from web.autorefresh import AutoRefresh
 
@@ -622,6 +628,108 @@ class LoadEnv(JobWidgetSimple):
         return None
 
 
+class Detach(JobWidgetSimple):
+    def __init__(self, jobset_ids, sql_session, workload=None, job_id=None):
+        super(Detach, self).__init__(jobset_ids, sql_session,
+            job_detach_s if workload else job_detach,
+            workload, job_id)
+        self._savedValue = ''
+        #self._w = CheckBox('Start in detach mode')
+        self._w = CheckBox()
+        self._w.setDescription(_("Whether the completion of the job must be\
+                                monitored or not (usefull to start daemons,\
+                                services or long running processes)"))
+        self._w.setImmediate(True)
+        self._addInheritedWidget(self._w)
+
+        if self._obj is not None:
+            self._w.setValue(bool(self._obj.detach))
+        else:
+            self._savedValue = bool(self._default_obj.detach)
+            self._setDefaultValue()
+            self._inherited.setValue(True)
+            self._doGreyOut()
+
+    def getFieldWidget(self):
+        return self._w
+
+    def _setDefaultValue(self):
+        self._w.setValue(bool(self._default_obj.detach))
+
+    def _saveValue(self):
+        self._savedValue = self._w.getValue()
+
+    def _restoreValue(self):
+        self._w.setValue(self._savedValue)
+
+    def setFocus(self):
+        self._w.focus()
+
+    def updateJob(self, job):
+        if self.isInherited():
+            try:
+                del job.job_detach
+            except:
+                pass
+            return None
+        v = int(self._w.getValue())
+        if self._workload is None:
+            job.job_detach = job_detach(v)
+        else:
+            job.job_detach = job_detach_s(v, self._workload)
+        return None
+
+
+class Manual(JobWidgetSimple):
+    def __init__(self, jobset_ids, sql_session, workload=None, job_id=None):
+        super(Manual, self).__init__(jobset_ids, sql_session,
+            job_manual_s if workload else job_manual,
+            workload, job_id)
+        self._savedValue = ''
+        self._w = CheckBox()
+        self._w.setDescription(_("Whether a confirmation must be asked to\
+                                 operators before starting the job"))
+        self._w.setImmediate(True)
+        self._addInheritedWidget(self._w)
+
+        if self._obj is not None:
+            self._w.setValue(bool(self._obj.manual))
+        else:
+            self._savedValue = bool(self._default_obj.manual)
+            self._setDefaultValue()
+            self._inherited.setValue(True)
+            self._doGreyOut()
+
+    def getFieldWidget(self):
+        return self._w
+
+    def _setDefaultValue(self):
+        self._w.setValue(bool(self._default_obj.manual))
+
+    def _saveValue(self):
+        self._savedValue = self._w.getValue()
+
+    def _restoreValue(self):
+        self._w.setValue(self._savedValue)
+
+    def setFocus(self):
+        self._w.focus()
+
+    def updateJob(self, job):
+        if self.isInherited():
+            try:
+                del job.job_manual
+            except:
+                pass
+            return None
+        v = int(self._w.getValue())
+        if self._workload is None:
+            job.job_manual = job_manual(v)
+        else:
+            job.job_manual = job_manual_s(v, self._workload)
+        return None
+
+
 class StartTimeError(Exception):
 
     """Syntax error in start time exception."""
@@ -967,3 +1075,46 @@ class CGroup(JobWidgetSimpleText):
         else:
             job.job_control_group = job_control_group_s(v, self._workload)
         return None
+
+
+class ManualCommand(JobWidgetSimpleText):
+    def __init__(self, jobset_ids, sql_session, descr,
+                 workload=None, job_id=None):
+        super(ManualCommand, self).__init__(jobset_ids, sql_session,
+                      job_manual_command_s if workload else job_manual_command,
+                      descr, workload, job_id)
+        if self._obj is not None:
+            self._w.setValue(self._obj.manual_command.encode('utf-8'))
+        else:
+            if self._default_obj:
+                self._savedValue = self._default_obj.manual_command.encode(
+                                                                    'utf-8')
+            else:
+                self._savedValue = ''
+            self._setDefaultValue()
+            if jobset_ids:
+                # Only if it's not the root jobset which is edited
+                self._inherited.setValue(True)
+                self._doGreyOut()
+
+    def _setDefaultValue(self):
+        if self._default_obj:
+            self._w.setValue(self._default_obj.manual_command.encode('utf-8'))
+        else:
+            self._w.setValue('')
+
+    def updateJob(self, job):
+        if self.isInherited():
+            try:
+                del job.job_manual_command
+            except:
+                pass
+            return None
+        v = self._w.getValue()
+        if v is None:
+            v = ''
+        if self._workload is None:
+            job.job_manual_command = job_manual_command(v)
+        else:
+            job.job_manual_command = job_manual_command_s(v, self._workload)
+        return None
