@@ -23,6 +23,7 @@ from muntjac.api import (Window, CheckBox, TextField, TextArea, TabSheet,
                          Label, VerticalLayout)
 from muntjac.ui.button import IClickListener
 from muntjac.ui.window import Notification
+from muntjac.terminal.sizeable import ISizeable
 
 import web.jobwidgets
 import web.commandargswidget
@@ -34,7 +35,8 @@ from tables.job_main_s import job_main_s
 
 
 (FOCUS_NONE, FOCUS_NAME, FOCUS_DESCR, FOCUS_CMD, FOCUS_ARG,
- FOCUS_OUT, FOCUS_ERR, FOCUS_USER, FOCUS_CGROUP) = 0, 1, 2, 3, 4, 5, 6, 7, 8
+ FOCUS_OUT, FOCUS_ERR, FOCUS_USER, FOCUS_CGROUP,
+ FOCUS_MANUALCMD) = 0, 1, 2, 3, 4, 5, 6, 7, 8, 9
 
 
 class JobWindow(Window, IClickListener):
@@ -163,13 +165,13 @@ class JobWindow(Window, IClickListener):
         v.setComponentAlignment(h_bt, Alignment.BOTTOM_RIGHT)
 
         # General
-        t1 = GridLayout(3, 10)
+        t1 = GridLayout(3, 6)
         t1.setStyleName("jobdetails")
         t1.setSizeFull()
         t1.setSpacing(True)
         t1.setMargin(True)
         t1.setColumnExpandRatio(1, 1.0)
-        t1.setRowExpandRatio(9, 1.0)
+        t1.setRowExpandRatio(5, 1.0)
 
         # General/Enabled
         l = Label(_("Enabled:"))
@@ -212,84 +214,18 @@ class JobWindow(Window, IClickListener):
                                      Alignment.MIDDLE_RIGHT)
         self._host = w
 
-        # General/Calendar
-        l = Label(_("Calendar:"))
-        l.setWidth(None)
-        t1.addComponent(l, 0, 3)
-        t1.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
-        w = web.calendarwidget.Calendar(self._jobset_ids,
-                                        application_window,
-                                        self._sql_session,
-                                        self._workload, self._job_id)
-        t1.addComponent(w.getFieldWidget(), 1, 3)
-        if workload is not None and job.rw_cal_id is False:
-            w.getFieldWidget().setEnabled(False)
-        elif not self._is_root:
-            t1.addComponent(w.getInheritedCheckbox(), 2, 3)
-            t1.setComponentAlignment(w.getInheritedCheckbox(),
-                                     Alignment.MIDDLE_RIGHT)
-        self._cal = w
-
-        # General/Start time
-        l = Label(_("Start time:"))
-        l.setWidth(None)
-        t1.addComponent(l, 0, 4)
-        t1.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
-        w = web.jobwidgets.StartTime(self._jobset_ids, session,
-                                      self._workload, self._job_id)
-        t1.addComponent(w.getFieldWidget(), 1, 4)
-        if workload is not None and job.rw_start_time is False:
-            w.getFieldWidget().setEnabled(False)
-        elif not self._is_root:
-            t1.addComponent(w.getInheritedCheckbox(), 2, 4)
-            t1.setComponentAlignment(w.getInheritedCheckbox(),
-                                     Alignment.MIDDLE_RIGHT)
-        self._start_time = w
-
-        # General/Start limit
-        l = Label(_("Start limit:"))
-        l.setWidth(None)
-        t1.addComponent(l, 0, 5)
-        t1.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
-        w = web.jobwidgets.StartLimit(self._jobset_ids, session,
-                                      self._workload, self._job_id)
-        t1.addComponent(w.getFieldWidget(), 1, 5)
-        if workload is not None and job.rw_job_start_limit is False:
-            w.getFieldWidget().setEnabled(False)
-        elif not self._is_root:
-            t1.addComponent(w.getInheritedCheckbox(), 2, 5)
-            t1.setComponentAlignment(w.getInheritedCheckbox(),
-                                     Alignment.MIDDLE_RIGHT)
-        self._start_limit = w
-
-        # General/Max duration
-        l = Label(_("Max duration:"))
-        l.setWidth(None)
-        t1.addComponent(l, 0, 6)
-        t1.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
-        w = web.jobwidgets.MaxDuration(self._jobset_ids, session,
-                                       self._workload, self._job_id)
-        t1.addComponent(w.getFieldWidget(), 1, 6)
-        if workload is not None and job.rw_job_max_duration is False:
-            w.getFieldWidget().setEnabled(False)
-        elif not self._is_root:
-            t1.addComponent(w.getInheritedCheckbox(), 2, 6)
-            t1.setComponentAlignment(w.getInheritedCheckbox(),
-                                     Alignment.MIDDLE_RIGHT)
-        self._max_duration = w
-
         # General/Retries
         l = Label(_("Retries:"))
         l.setWidth(None)
-        t1.addComponent(l, 0, 7)
+        t1.addComponent(l, 0, 3)
         t1.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
         w = web.jobwidgets.Retries(self._jobset_ids, session,
                                    self._workload, self._job_id)
-        t1.addComponent(w.getFieldWidget(), 1, 7)
+        t1.addComponent(w.getFieldWidget(), 1, 3)
         if workload is not None and job.rw_job_retries is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
-            t1.addComponent(w.getInheritedCheckbox(), 2, 7)
+            t1.addComponent(w.getInheritedCheckbox(), 2, 3)
             t1.setComponentAlignment(w.getInheritedCheckbox(),
                                      Alignment.MIDDLE_RIGHT)
         self._retries = w
@@ -297,15 +233,15 @@ class JobWindow(Window, IClickListener):
         # General/Wait retries
         l = Label(_("Wait retries:"))
         l.setWidth(None)
-        t1.addComponent(l, 0, 8)
+        t1.addComponent(l, 0, 4)
         t1.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
         w = web.jobwidgets.RetryInterval(self._jobset_ids, session,
                                           self._workload, self._job_id)
-        t1.addComponent(w.getFieldWidget(), 1, 8)
+        t1.addComponent(w.getFieldWidget(), 1, 4)
         if workload is not None and job.rw_job_retries_interval is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
-            t1.addComponent(w.getInheritedCheckbox(), 2, 8)
+            t1.addComponent(w.getInheritedCheckbox(), 2, 4)
             t1.setComponentAlignment(w.getInheritedCheckbox(),
                                      Alignment.MIDDLE_RIGHT)
         self._retry_interval = w
@@ -315,116 +251,247 @@ class JobWindow(Window, IClickListener):
             self._descr.setEnabled(job.rw_description)
         if not self._is_root:
             self._descr.setSizeFull()
-            t1.addComponent(self._descr, 0, 9, 2, 9)
+            t1.addComponent(self._descr, 0, 5, 2, 5)
 
-        # Command
-        t2 = GridLayout(3, 7)
+        # Triggers
+        t2 = GridLayout(3, 6)
         t2.setStyleName("jobdetails")
-        t2.setSizeFull()
+        t2.setWidth(100, ISizeable.UNITS_PERCENTAGE)
         t2.setSpacing(True)
         t2.setMargin(True)
         t2.setColumnExpandRatio(1, 1.0)
-        t2.setRowExpandRatio(6, 1.0)
 
-        # Command/Command
-        l = Label(_("Command:"))
+        # Triggers/Calendar
+        l = Label(_("Calendar:"))
         l.setWidth(None)
         t2.addComponent(l, 0, 0)
         t2.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
-        w = web.jobwidgets.Command(self._jobset_ids, session,
-                                _("Command to run (without its arguments) \
-                                If empty no command will be run"),
-                            self._workload, self._job_id)
+        w = web.calendarwidget.Calendar(self._jobset_ids,
+                                        application_window,
+                                        self._sql_session,
+                                        self._workload, self._job_id)
         t2.addComponent(w.getFieldWidget(), 1, 0)
-        if workload is not None and job.rw_job_command is False:
+        if workload is not None and job.rw_cal_id is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
             t2.addComponent(w.getInheritedCheckbox(), 2, 0)
             t2.setComponentAlignment(w.getInheritedCheckbox(),
                                      Alignment.MIDDLE_RIGHT)
+        self._cal = w
+
+        # Triggers/Start time
+        l = Label(_("Start time:"))
+        l.setWidth(None)
+        t2.addComponent(l, 0, 1)
+        t2.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
+        w = web.jobwidgets.StartTime(self._jobset_ids, session,
+                                      self._workload, self._job_id)
+        t2.addComponent(w.getFieldWidget(), 1, 1)
+        if workload is not None and job.rw_start_time is False:
+            w.getFieldWidget().setEnabled(False)
+        elif not self._is_root:
+            t2.addComponent(w.getInheritedCheckbox(), 2, 1)
+            t2.setComponentAlignment(w.getInheritedCheckbox(),
+                                     Alignment.MIDDLE_RIGHT)
+        self._start_time = w
+
+        # Triggers/Start limit
+        l = Label(_("Start limit:"))
+        l.setWidth(None)
+        t2.addComponent(l, 0, 2)
+        t2.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
+        w = web.jobwidgets.StartLimit(self._jobset_ids, session,
+                                      self._workload, self._job_id)
+        t2.addComponent(w.getFieldWidget(), 1, 2)
+        if workload is not None and job.rw_job_start_limit is False:
+            w.getFieldWidget().setEnabled(False)
+        elif not self._is_root:
+            t2.addComponent(w.getInheritedCheckbox(), 2, 2)
+            t2.setComponentAlignment(w.getInheritedCheckbox(),
+                                     Alignment.MIDDLE_RIGHT)
+        self._start_limit = w
+
+        # Triggers/Max duration
+        l = Label(_("Max duration:"))
+        l.setWidth(None)
+        t2.addComponent(l, 0, 3)
+        t2.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
+        w = web.jobwidgets.MaxDuration(self._jobset_ids, session,
+                                       self._workload, self._job_id)
+        t2.addComponent(w.getFieldWidget(), 1, 3)
+        if workload is not None and job.rw_job_max_duration is False:
+            w.getFieldWidget().setEnabled(False)
+        elif not self._is_root:
+            t2.addComponent(w.getInheritedCheckbox(), 2, 3)
+            t2.setComponentAlignment(w.getInheritedCheckbox(),
+                                     Alignment.MIDDLE_RIGHT)
+        self._max_duration = w
+
+        # Triggers/Manual
+        l = Label(_("Manual:"))
+        l.setWidth(None)
+        t2.addComponent(l, 0, 4)
+        t2.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
+        w = web.jobwidgets.Manual(self._jobset_ids, session,
+                                  self._workload, self._job_id)
+        t2.addComponent(w.getFieldWidget(), 1, 4)
+        if workload is not None and job.rw_job_manual is False:
+            w.getFieldWidget().setEnabled(False)
+        elif not self._is_root:
+            t2.addComponent(w.getInheritedCheckbox(), 2, 4)
+            t2.setComponentAlignment(w.getInheritedCheckbox(),
+                                     Alignment.MIDDLE_RIGHT)
+        self._manual = w
+
+        # Triggers/Manual Command
+        l = Label(_("Command:"))
+        l.setWidth(None)
+        t2.addComponent(l, 0, 5)
+        t2.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
+        w = web.jobwidgets.ManualCommand(self._jobset_ids, session,
+                                _("Command to run to alert of a waiting manual\
+                                job. If empty no command will be run. The\
+                                following environment variables are set:\
+                                SCHEDWI_TEMPLATE (the path to a text file that\
+                                contains the message to send to operators),\
+                                SCHEDWI_JOBPATH, SCHEDWI_JOBID,\
+                                SCHEDWI_START_TIME, SCHEDWI_START_TIME_EPOCH,\
+                                SCHEDWI_TIME_LIMIT and\
+                                SCHEDWI_TIME_LIMIT_EPOCH"),
+                            self._workload, self._job_id)
+        t2.addComponent(w.getFieldWidget(), 1, 5)
+        if workload is not None and job.rw_job_manual_command is False:
+            w.getFieldWidget().setEnabled(False)
+        elif not self._is_root:
+            t2.addComponent(w.getInheritedCheckbox(), 2, 5)
+            t2.setComponentAlignment(w.getInheritedCheckbox(),
+                                     Alignment.MIDDLE_RIGHT)
+        self._manual_command = w
+
+        # Command
+        t3 = GridLayout(3, 8)
+        t3.setStyleName("jobdetails")
+        t3.setSizeFull()
+        t3.setSpacing(True)
+        t3.setMargin(True)
+        t3.setColumnExpandRatio(1, 1.0)
+        t3.setRowExpandRatio(7, 1.0)
+
+        # Command/Command
+        l = Label(_("Command:"))
+        l.setWidth(None)
+        t3.addComponent(l, 0, 0)
+        t3.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
+        w = web.jobwidgets.Command(self._jobset_ids, session,
+                                _("Command to run (without its arguments) \
+                                If empty no command will be run"),
+                            self._workload, self._job_id)
+        t3.addComponent(w.getFieldWidget(), 1, 0)
+        if workload is not None and job.rw_job_command is False:
+            w.getFieldWidget().setEnabled(False)
+        elif not self._is_root:
+            t3.addComponent(w.getInheritedCheckbox(), 2, 0)
+            t3.setComponentAlignment(w.getInheritedCheckbox(),
+                                     Alignment.MIDDLE_RIGHT)
         self._command = w
 
         # Command/Username
         l = Label(_("Username:"))
         l.setWidth(None)
-        t2.addComponent(l, 0, 1)
-        t2.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
+        t3.addComponent(l, 0, 1)
+        t3.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
         w = web.jobwidgets.Username(self._jobset_ids, session,
                             _("System user name used to run the command"),
                             self._workload, self._job_id)
-        t2.addComponent(w.getFieldWidget(), 1, 1)
+        t3.addComponent(w.getFieldWidget(), 1, 1)
         if workload is not None and job.rw_job_username is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
-            t2.addComponent(w.getInheritedCheckbox(), 2, 1)
-            t2.setComponentAlignment(w.getInheritedCheckbox(),
+            t3.addComponent(w.getInheritedCheckbox(), 2, 1)
+            t3.setComponentAlignment(w.getInheritedCheckbox(),
                                      Alignment.MIDDLE_RIGHT)
         self._username = w
 
         # Command/stdout
         l = Label(_("Standard output file:"))
         l.setWidth(None)
-        t2.addComponent(l, 0, 2)
-        t2.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
+        t3.addComponent(l, 0, 2)
+        t3.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
         w = web.jobwidgets.Stdout(self._jobset_ids, session,
                             _("Output file name (empty means no file)"),
                             self._workload, self._job_id)
-        t2.addComponent(w.getFieldWidget(), 1, 2)
+        t3.addComponent(w.getFieldWidget(), 1, 2)
         if workload is not None and job.rw_job_file_out is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
-            t2.addComponent(w.getInheritedCheckbox(), 2, 2)
-            t2.setComponentAlignment(w.getInheritedCheckbox(),
+            t3.addComponent(w.getInheritedCheckbox(), 2, 2)
+            t3.setComponentAlignment(w.getInheritedCheckbox(),
                                      Alignment.MIDDLE_RIGHT)
         self._stdout = w
 
         # Command/stderr
         l = Label(_("Standard error file:"))
         l.setWidth(None)
-        t2.addComponent(l, 0, 3)
-        t2.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
+        t3.addComponent(l, 0, 3)
+        t3.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
         w = web.jobwidgets.Stderr(self._jobset_ids, session,
                             _("Error file name (empty means no file)"),
                             self._workload, self._job_id)
-        t2.addComponent(w.getFieldWidget(), 1, 3)
+        t3.addComponent(w.getFieldWidget(), 1, 3)
         if workload is not None and job.rw_job_file_err is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
-            t2.addComponent(w.getInheritedCheckbox(), 2, 3)
-            t2.setComponentAlignment(w.getInheritedCheckbox(),
+            t3.addComponent(w.getInheritedCheckbox(), 2, 3)
+            t3.setComponentAlignment(w.getInheritedCheckbox(),
                                      Alignment.MIDDLE_RIGHT)
         self._stderr = w
 
         # Command/Error code
         l = Label(_("Success return code:"))
         l.setWidth(None)
-        t2.addComponent(l, 0, 4)
-        t2.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
+        t3.addComponent(l, 0, 4)
+        t3.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
         w = web.jobwidgets.ReturnCode(self._jobset_ids, session,
                                       self._workload, self._job_id)
-        t2.addComponent(w.getFieldWidget(), 1, 4)
+        t3.addComponent(w.getFieldWidget(), 1, 4)
         if workload is not None and job.rw_job_success_return_code is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
-            t2.addComponent(w.getInheritedCheckbox(), 2, 4)
-            t2.setComponentAlignment(w.getInheritedCheckbox(),
+            t3.addComponent(w.getInheritedCheckbox(), 2, 4)
+            t3.setComponentAlignment(w.getInheritedCheckbox(),
                                      Alignment.MIDDLE_RIGHT)
         self._return_code = w
 
+        # Command/Detach
+        l = Label(_("Start in detach mode:"))
+        l.setWidth(None)
+        t3.addComponent(l, 0, 5)
+        t3.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
+        w = web.jobwidgets.Detach(self._jobset_ids, session,
+                                   self._workload, self._job_id)
+        t3.addComponent(w.getFieldWidget(), 1, 5)
+        if workload is not None and job.rw_job_detach is False:
+            w.getFieldWidget().setEnabled(False)
+        elif not self._is_root:
+            t3.addComponent(w.getInheritedCheckbox(), 2, 5)
+            t3.setComponentAlignment(w.getInheritedCheckbox(),
+                                     Alignment.MIDDLE_RIGHT)
+        self._detach = w
+
         # Command/cgroup
         l = Label(_("Linux Control Group:"))
         l.setWidth(None)
-        t2.addComponent(l, 0, 5)
-        t2.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
+        t3.addComponent(l, 0, 6)
+        t3.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
         w = web.jobwidgets.CGroup(self._jobset_ids, session,
                             _("Control Group name"),
                             self._workload, self._job_id)
-        t2.addComponent(w.getFieldWidget(), 1, 5)
+        t3.addComponent(w.getFieldWidget(), 1, 6)
         if workload is not None and job.rw_job_control_group is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
-            t2.addComponent(w.getInheritedCheckbox(), 2, 5)
-            t2.setComponentAlignment(w.getInheritedCheckbox(),
+            t3.addComponent(w.getInheritedCheckbox(), 2, 6)
+            t3.setComponentAlignment(w.getInheritedCheckbox(),
                                      Alignment.MIDDLE_RIGHT)
         self._cgroup = w
 
@@ -433,29 +500,29 @@ class JobWindow(Window, IClickListener):
                                               application_window, session,
                                               self._workload, self._job_id)
         w.getFieldWidget().setWidth("100%")
-        t2.addComponent(w.getFieldWidget(), 0, 6, 1, 6)
+        t3.addComponent(w.getFieldWidget(), 0, 7, 1, 7)
         if workload is not None and job.rw_job_arguments is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
-            t2.addComponent(w.getInheritedCheckbox(), 2, 6)
-            t2.setComponentAlignment(w.getInheritedCheckbox(),
+            t3.addComponent(w.getInheritedCheckbox(), 2, 7)
+            t3.setComponentAlignment(w.getInheritedCheckbox(),
                                      Alignment.MIDDLE_RIGHT)
         self._args = w
 
         self._sql_session.close_session(session)
 
         # Environments
-        t3 = VerticalLayout()
-        t3.setSizeFull()
-        t3.setSpacing(True)
-        t3.setMargin(True)
+        t4 = VerticalLayout()
+        t4.setSizeFull()
+        t4.setSpacing(True)
+        t4.setMargin(True)
 
         # Environments/Load user environment (.profile, ...)
         le = HorizontalLayout()
         le.setWidth('100%')
         le.setSpacing(True)
         le.setMargin(False)
-        t3.addComponent(le)
+        t4.addComponent(le)
 
         w = web.jobwidgets.LoadEnv(self._jobset_ids, session,
                                    self._workload, self._job_id)
@@ -472,20 +539,22 @@ class JobWindow(Window, IClickListener):
                                     self._host,
                                     self._sql_session, self._workload,
                                     self._job_id)
-        t3.addComponent(e)
-        t3.setExpandRatio(e, 1.0)
+        t4.addComponent(e)
+        t4.setExpandRatio(e, 1.0)
         if workload is not None and job.rw_job_environment is False:
             e.setEnabled(False)
         self._env = e
 
         # Add the components to the tab sheet
         ts.addTab(t1, _('General'))
-        ts.addTab(t2, _('Command'))
-        ts.addTab(t3, _('Environments'))
+        ts.addTab(t2, _('Triggers'))
+        ts.addTab(t3, _('Command'))
+        ts.addTab(t4, _('Environments'))
         self._ts = ts
         self._t1 = t1
         self._t2 = t2
         self._t3 = t3
+        self._t4 = t4
 
         application_window.addWindow(self)
         if x is None or y is None:
@@ -501,22 +570,25 @@ class JobWindow(Window, IClickListener):
             self._ts.setSelectedTab(self._t1)
             self._descr.focus()
         elif focus == FOCUS_CMD:
-            self._ts.setSelectedTab(self._t2)
+            self._ts.setSelectedTab(self._t3)
             self._command.setFocus()
         elif focus == FOCUS_USER:
-            self._ts.setSelectedTab(self._t2)
+            self._ts.setSelectedTab(self._t3)
             self._username.setFocus()
         elif focus == FOCUS_OUT:
-            self._ts.setSelectedTab(self._t2)
+            self._ts.setSelectedTab(self._t3)
             self._stdout.setFocus()
         elif focus == FOCUS_ERR:
-            self._ts.setSelectedTab(self._t2)
+            self._ts.setSelectedTab(self._t3)
             self._stderr.setFocus()
         elif focus == FOCUS_CGROUP:
-            self._ts.setSelectedTab(self._t2)
+            self._ts.setSelectedTab(self._t3)
             self._cgroup.setFocus()
-        elif focus == FOCUS_ARG:
+        elif focus == FOCUS_MANUALCMD:
             self._ts.setSelectedTab(self._t2)
+            self._manual_command.setFocus()
+        elif focus == FOCUS_ARG:
+            self._ts.setSelectedTab(self._t3)
             self._args.setFocus()
 
     def buttonClick(self, event):
@@ -630,6 +702,9 @@ class JobWindow(Window, IClickListener):
             self._args.updateJob(job)
             self._env.updateJob(job)
             self._loadenv.updateJob(job)
+            self._detach.updateJob(job)
+            self._manual.updateJob(job)
+            self._manual_command.updateJob(job)
             msg = self._return_code.updateJob(job)
             if msg:
                 self._sql_session.cancel_session(session)
@@ -637,7 +712,7 @@ class JobWindow(Window, IClickListener):
                         _("Wrong value for the return code"),
                         '<br/>' + msg,
                         Notification.TYPE_ERROR_MESSAGE)
-                self._ts.setSelectedTab(self._t2)
+                self._ts.setSelectedTab(self._t3)
                 return
             if self._job_id is None:
                 session.add(job)
