@@ -20,18 +20,20 @@
 
 from muntjac.api import (VerticalLayout, Table, HorizontalLayout, Button,
                          Window, Alignment, NativeSelect)
-from muntjac.ui.window import Notification
+from muntjac.ui.window import (Notification, IResizeListener)
 from muntjac.data.util.indexed_container import IndexedContainer
 from muntjac.terminal.theme_resource import ThemeResource
 from muntjac.data.property import IValueChangeListener
 from muntjac.ui.button import IClickListener
 from muntjac.ui.table import ICellStyleGenerator
+from muntjac.terminal.sizeable import ISizeable
 
 from web.jobtable import JobTableListener
 from web.cutcopypastemenu import GenericContextMenu
 from web.selectjobwidget import SelectJob
 from web.boxes import DeleteBox, BoxCloseListener
 from web.autorefresh import AutoRefresh
+from web.link_graph import LinkGraph
 import path
 import status_utils
 from simple_queries_job import sql_get_job
@@ -84,16 +86,17 @@ class Links(HorizontalLayout, JobTableListener):
         self.addComponent(self._table)
         self.setExpandRatio(self._table, 1.0)
 
+        btbox = VerticalLayout()
+        btbox.setSpacing(True)
+        btbox.setMargin(False)
+        btbox.setWidth('110px')
+
         if workload is None or job_main_s.rw_links is True:
             self._table.setSelectable(True)
             self._table.addListener(SelectionHandler(self),
                                     IValueChangeListener)
             self._table.addActionHandler(LinkContextMenu(self))
 
-            btbox = VerticalLayout()
-            btbox.setSpacing(True)
-            btbox.setMargin(False)
-            btbox.setWidth('110px')
             b = Button(_('Edit'))
             b.setIcon(ThemeResource('icons/edit.png'))
             b.setDescription(_("Edit the dependency link"))
@@ -121,7 +124,15 @@ class Links(HorizontalLayout, JobTableListener):
             btbox.addComponent(b)
             self._btdel = b
 
-            self.addComponent(btbox)
+        b = Button(_('Preview'))
+        b.setIcon(ThemeResource('icons/graph.png'))
+        b.setDescription(_("Preview the dependency tree"))
+        b.setEnabled(False)
+        b.setWidth('100%')
+        b.addListener(PreviewBtHandler(self), IClickListener)
+        btbox.addComponent(b)
+        self._btpreview = b
+        self.addComponent(btbox)
 
         jobTable.add_listener(self)
 
@@ -193,9 +204,11 @@ class Links(HorizontalLayout, JobTableListener):
             self._sql_session.close_session(session)
             if self._workload is None or job_main_s.rw_links is True:
                 self._btadd.setEnabled(True)
+            self._btpreview.setEnabled(True)
         else:
             if self._workload is None or job_main_s.rw_links is True:
                 self._btadd.setEnabled(False)
+            self._btpreview.setEnabled(False)
 
         self._table.setContainerDataSource(self._container)
 #        if new_selection_id:
@@ -264,6 +277,16 @@ class EditBtHandler(IClickListener):
             WindowLink(self._c, r)
 
 
+class PreviewBtHandler(IClickListener):
+    def __init__(self, link_obj):
+        super(PreviewBtHandler, self).__init__()
+        self._c = link_obj
+
+    def buttonClick(self, event):
+        AutoRefresh.reset()
+        WindowPreview(self._c)
+
+
 class DeleteBtHandler(IClickListener):
     def __init__(self, link_obj):
         super(DeleteBtHandler, self).__init__()
@@ -579,3 +602,80 @@ class WindowLink(IClickListener):
 
         # Close the window
         self._c.getWindow().removeWindow(self._w)
+
+
+class WindowPreview(IClickListener, IResizeListener):
+
+    """Window to display the dependency tree graph."""
+
+    def __init__(self, link_obj):
+        """Create and display the window.
+
+        @param link_obj:
+                    the associated L{Links} object.
+        """
+        super(WindowPreview, self).__init__()
+        self._c = link_obj
+
+        window_width = 250
+        window_height = 405
+
+        # Whenever the user resizes the preview window (this window),
+        # the canvas in the CustomLayout must be resized accordingly.
+        # The size of the canvas is computed from the window size.
+        # The get the canvas size, self._canvas_width_delta and
+        # self._canvas_height_delta are substracted from the window
+        # size.
+        self._canvas_width_delta = 0
+        self._canvas_height_delta = 120
+        self._canvas_id = "canvasgraph"
+
+        self._w = Window(_("Link Dependency Graph"))
+        self._w.setWidth(window_width, ISizeable.UNITS_PIXELS)
+        self._w.setHeight(window_height, ISizeable.UNITS_PIXELS)
+        self._w.setImmediate(True)
+        self._w.addListener(self, IResizeListener)
+
+        # VerticalLayout as content by default
+        v = self._w.getContent()
+        v.setSizeFull()
+        v.setMargin(False)
+        v.setSpacing(False)
+
+        # CustomLayout that contains the canvas which is used to draw
+        # the graph (through the Paper.js javascript library)
+        l = LinkGraph(self._c._job, self._canvas_id,
+                      window_width - self._canvas_width_delta,
+                      window_height - self._canvas_height_delta,
+                      self._c._sql_session, self._c._workload)
+        v.addComponent(l)
+        v.setExpandRatio(l, 1.0)
+
+        # Close button
+        h_bt = HorizontalLayout()
+        h_bt.setMargin(True)
+        h_bt.setSpacing(False)
+        ok = Button(_('Close'))
+        ok.addListener(self, IClickListener)
+        h_bt.addComponent(ok)
+        v.addComponent(h_bt)
+        v.setComponentAlignment(h_bt, Alignment.BOTTOM_RIGHT)
+
+        self._c.getWindow().addWindow(self._w)
+        self._w.center()
+
+    def windowResized(self, event):
+        """Callback for the resize of the window."""
+        h = self._w.getHeight()
+        w = self._w.getWidth()
+        self._w.getParent().executeJavaScript("""
+            var canvas = document.getElementById("%s");
+            canvas.paper_obj.view.viewSize = new canvas.paper_obj.Size(%d, %d);
+        """ % (self._canvas_id,
+               w - self._canvas_width_delta, h - self._canvas_height_delta))
+        self._w.requestRepaintAll()
+
+    def buttonClick(self, event):
+        """Callback for the close button."""
+        AutoRefresh.reset()
+        self._c.getWindow().removeWindow(self._w)
