@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2011 Herve Quatremain
+   Copyright (C) 2011-2013 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -83,6 +83,7 @@ extern int errno;
 #include <lib_functions.h>
 #include <utils.h>
 #include <lwc_log.h>
+#include <conf.h>
 #include <cert_utils.h>
 
 
@@ -172,95 +173,15 @@ my_chown (const char *filename, const char *user, const char *group)
 {
 	uid_t uid;
 	gid_t gid;
-	unsigned int i;
-#if HAVE_GETPWNAM || HAVE_GETPWENT
-	struct passwd *pass;
-#endif
-#if HAVE_GETGRNAM || HAVE_GETGRENT
-	struct group *group_str;
-#endif
-
 
 	if (filename == NULL) {
 		return 0;
 	}
 
-	if (user == NULL) {
-		uid = -1;
-	}
-	else {
-		for (i = 0; user[i] != '\0' && isspace (user[i]) != 0; i++);
-		if (user[i] == '\0') {
-			uid = -1;
-		}
-		else if (isdigit (user[i]) != 0) {
-			uid = (uid_t) atoi (user + i);
-		}
-		else {
-
-#if HAVE_GETPWNAM
-
-			pass = getpwnam (user + i);
-			if (pass == NULL) {
-				return -1;
-			}
-			uid = pass->pw_uid;
-
-#elif HAVE_GETPWENT && HAVE_ENDPWENT
-
-			uid = -1;
-			while ((pass = getpwent()) != NULL) {
-				if (strcmp (pass->pw_name, user + i) == 0) {
-					uid = pass->pw_uid;
-					break;
-				}
-			}
-			endpwent ();
-#else
-			uid = -1;
-#endif
-		}
-	}
-
-
-	if (group == NULL) {
-		gid = -1;
-	}
-	else {
-		for (i = 0; group[i] != '\0' && isspace (group[i]) != 0; i++);
-		if (group[i] == '\0') {
-			gid = -1;
-		}
-		else if (isdigit (group[i]) != 0) {
-			gid = (gid_t) atoi (group + i);
-		}
-		else {
-
-#if HAVE_GETGRNAM
-
-			group_str = getgrnam (group + i);
-			if (group_str == NULL) {
-				return -1;
-			}
-			gid = group_str->gr_gid;
-
-#elif HAVE_GETGRENT && HAVE_ENDGRENT
-
-			gid = -1;
-			while ((group_str = getgrent()) != NULL) {
-				if (strcmp (group_str->gr_name, group +i) == 0)
-				{
-					gid = group_str->gr_gid;
-					break;
-				}
-			}
-			endgrent ();
-#else
-			gid = -1;
-#endif
-		}
-	}
-
+	uid = -1;
+	get_userid (user, &uid);
+	gid = -1;
+	get_groupid (group, &gid);
 
 	if (uid == -1 && gid == -1) {
 		return 0;
@@ -445,12 +366,22 @@ generate_request (gnutls_x509_privkey_t key,
 	gnutls_x509_crq_t crq;
 	int ret, len, i;
 	unsigned char net_ip[20];
+	const char *conf_c, *conf_o, *conf_ou, *conf_l, *conf_st;
 
 
 #if HAVE_ASSERT_H
 	assert (dnsnames != NULL && *dnsnames != NULL && **dnsnames != '\0');
 #endif
 
+	ret  = conf_get_param_string ("SSLCACountry", &conf_c);
+	ret += conf_get_param_string ("SSLCAOrganization", &conf_o);
+	ret += conf_get_param_string ("SSLCAUnit", &conf_ou);
+	ret += conf_get_param_string ("SSLCALocality", &conf_l);
+	ret += conf_get_param_string ("SSLCAState", &conf_st);
+#if HAVE_ASSERT_H
+	assert (ret == 0);
+#endif
+
 	ret = gnutls_x509_crq_init (&crq);
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
@@ -461,60 +392,56 @@ generate_request (gnutls_x509_privkey_t key,
 
 	/* Set the DN */
 	ret = gnutls_x509_crq_set_dn_by_oid (crq,
-					GNUTLS_OID_X520_COUNTRY_NAME, 0,
-					COUNTRY,
-					schedwi_strlen (COUNTRY));
+				GNUTLS_OID_X520_COUNTRY_NAME, 0,
+				conf_c, schedwi_strlen (conf_c));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the COUNTRY (%s): %s"),
-			COUNTRY, gnutls_strerror (ret));
+			conf_c, gnutls_strerror (ret));
 		gnutls_x509_crq_deinit (crq);
 		return NULL;
 	}
 
 	ret = gnutls_x509_crq_set_dn_by_oid (crq,
-					GNUTLS_OID_X520_ORGANIZATION_NAME, 0,
-					ORGANIZATION,
-					schedwi_strlen (ORGANIZATION));
+			GNUTLS_OID_X520_ORGANIZATION_NAME, 0,
+			conf_o, schedwi_strlen (conf_o));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the ORGANIZATION (%s): %s"),
-			ORGANIZATION, gnutls_strerror (ret));
+			conf_o, gnutls_strerror (ret));
 		gnutls_x509_crq_deinit (crq);
 		return NULL;
 	}
 
 	ret = gnutls_x509_crq_set_dn_by_oid (crq,
 				GNUTLS_OID_X520_ORGANIZATIONAL_UNIT_NAME, 0,
-				OU, schedwi_strlen (OU));
+				conf_ou, schedwi_strlen (conf_ou));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the ORGANIZATIONAL UNIT (%s): %s"),
-			OU, gnutls_strerror (ret));
+			conf_ou, gnutls_strerror (ret));
 		gnutls_x509_crq_deinit (crq);
 		return NULL;
 	}
 
 	ret = gnutls_x509_crq_set_dn_by_oid (crq,
-					GNUTLS_OID_X520_LOCALITY_NAME, 0,
-					LOCALITY,
-					schedwi_strlen (LOCALITY));
+				GNUTLS_OID_X520_LOCALITY_NAME, 0,
+				conf_l, schedwi_strlen (conf_l));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the LOCALITY (%s): %s"),
-			LOCALITY, gnutls_strerror (ret));
+			conf_l, gnutls_strerror (ret));
 		gnutls_x509_crq_deinit (crq);
 		return NULL;
 	}
 
 	ret = gnutls_x509_crq_set_dn_by_oid (crq,
 				GNUTLS_OID_X520_STATE_OR_PROVINCE_NAME, 0,
-				STATE,
-				schedwi_strlen (STATE));
+				conf_st, schedwi_strlen (conf_st));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the STATE (%s): %s"),
-			STATE, gnutls_strerror (ret));
+			conf_st, gnutls_strerror (ret));
 		gnutls_x509_crq_deinit (crq);
 		return NULL;
 	}
