@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2013 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -77,9 +77,6 @@ extern int errno;
 /* Number of second to sleep between each scan of the user command table */
 #define COMMANDS_SCAN_SLEEP 20
 
-/* Number of hours between purge of the old user commands */
-#define COMMANDS_PURGE 36
-
 
 static pthread_t commands_thread;
 
@@ -231,8 +228,6 @@ commands_thread_run (void *obj)
 	load_workload_class_ptr ptr = (load_workload_class_ptr) obj;
 	lwc_LL *command_list;
 	command_action_ptr command_ptr;
-	char *err_msg;
-	unsigned int purge_time_counter;
 #if HAVE_NANOSLEEP
 	struct timespec req;
 
@@ -250,26 +245,6 @@ commands_thread_run (void *obj)
 	/* Install the cleanup callback */
 	pthread_cleanup_push (thread_clean, NULL);
 
-	/* Start by a purge of the old commands */
-	err_msg = NULL;
-	if (command_purge (&err_msg) != 0) {
-		if (err_msg != NULL) {
-			lwc_writeLog (	LOG_ERR,
-				_("Failed to purge old user commands: %s"),
-					err_msg);
-		}
-		else {
-			lwc_writeLog (	LOG_ERR,
-				_("Failed to purge old user commands"));
-		}
-	}
-	if (err_msg != NULL) {
-		free (err_msg);
-	}
-
-	/* Number of sleeps before purging the old user commands */
-	purge_time_counter = COMMANDS_PURGE * 3600 / COMMANDS_SCAN_SLEEP;
-
 	/* Run the scan of commands every COMMANDS_SCAN_SLEEP */
 	while (1) {
 
@@ -308,34 +283,6 @@ commands_thread_run (void *obj)
 		usleep (COMMANDS_SCAN_SLEEP * 1000000);
 #endif
 		pthread_testcancel ();
-
-		/* Purge the old user commands */
-		if (purge_time_counter == 0) {
-			err_msg = NULL;
-			if (command_purge (&err_msg) != 0) {
-				if (err_msg != NULL) {
-					lwc_writeLog (	LOG_ERR,
-				_("Failed to purge old user commands: %s"),
-							err_msg);
-				}
-				else {
-					lwc_writeLog (	LOG_ERR,
-				_("Failed to purge old user commands"));
-				}
-			}
-			if (err_msg != NULL) {
-				free (err_msg);
-			}
-
-			/* Reset the counter */
-			purge_time_counter =	  COMMANDS_PURGE * 3600
-						/ COMMANDS_SCAN_SLEEP;
-		}
-		else {
-			purge_time_counter--;
-		}
-
-		pthread_testcancel ();
 	}
 	pthread_cleanup_pop (1);
 	return NULL;
