@@ -35,6 +35,7 @@ static conf_param_t params_clnt[] = {
 	{ "DATE_FORMAT", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_DATEFORMAT},
 	{ "PID_FILE", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_PIDFILE},
 	{ "PID_FILE_REGISTRAR", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_PIDFILE_REG},
+	{ "MANUAL_TRIGGER_TEMPLATE_FILE", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_MANUAL_TRIGGER_TEMPLATE_FILE},
 	{ "WORKLOAD_PURGE_COMPLETED", INT, {0}, check_int, 0, 0, SCHEDWI_DEFAULT_WORKLOAD_PURGE_COMPLETED},
 	{ "WORKLOAD_PURGE_FAILED", INT, {0}, check_int, 0, 0, SCHEDWI_DEFAULT_WORKLOAD_PURGE_FAILED},
 	{ "ALLOW_FROM", STRING, {0}, check_netlist, 0, 0, ""},
@@ -44,9 +45,17 @@ static conf_param_t params_clnt[] = {
 	{ "IFACE_LISTEN", STRING, {0}, 0, 0, 0, 0},
 	{ "SSLCertificateFile", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_SSL_CERTIFICATE_FILE},
 	{ "SSLCertificateKeyFile", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_SSL_CERTIFICATE_KEY_FILE},
+	{ "SSLCommonName", STRING, {0}, 0, 0, 0, 0},
 	{ "SSLCACertificateFile", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_SSL_CA_CERTIFICATE_FILE},
 	{ "SSLCACertificateKeyFile", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_SSL_CA_CERTIFICATE_KEY_FILE},
 	{ "SSLCACRLFile", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_SSL_CA_CRL_FILE},
+	{ "SSLCACountry", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_SSL_COUNTRY},
+	{ "SSLCAOrganization", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_SSL_ORGANIZATION},
+	{ "SSLCAUnit", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_SSL_OU},
+	{ "SSLCALocality", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_SSL_LOCALITY},
+	{ "SSLCAState", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_SSL_STATE},
+	{ "SSLCACommonName", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_SSL_CA_CN},
+	{ "SSLCAEmail", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_SSL_CA_EMAIL},
 	{ "SSLAgentCertificateDir", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_SSL_CLNT_CERTIFICATE_DIR},
 	{ "SSLAgentRequestDir", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_SSL_CLNT_REQUEST_DIR},
 	{ "SSLAgentSaveRequestDir", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_SSL_CLNT_SAVE_REQUEST_DIR},
@@ -67,6 +76,8 @@ static conf_param_t params_clnt[] = {
 	{ "GUI_PORT", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_GUI_PORT},
 	{ "GUI_LOG_FILE", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_GUI_LOGFILE},
 	{ "GUI_CONTEXT_ROOT", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_GUI_CONTEXT_ROOT},
+	{ "PAM_AUTH", BOOL, {0}, check_bool, 0, 0, "0"},
+	{ "PAM_AUTH_SERVICE", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_PAM_AUTH_SERVICE},
 	{ "MODULE_DIR", FUNCTION, {0}, 0, module_path, 0, 0},
 	{ "MODULE_LOAD", FUNCTION, {0}, 0, module_load, 0, 0},
 	{ 0, INT, {0}, 0, 0, 0, 0}
