@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2010 Herve Quatremain
+   Copyright (C) 2007-2013 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -90,6 +90,7 @@ job_status_set (unsigned long long int id,
 		unsigned int status_time,
 		long int duration,
 		int retry_num,
+		int wait_reason,
 		const char *error_message)
 {
 	int j_status;
@@ -103,6 +104,7 @@ job_status_set (unsigned long long int id,
 				id_str, j_status,
 				(status_time == 0) ? time (NULL): status_time,
 				retry_num,
+				wait_reason,
 				error_message,
 				sql_status_set_error_logger, NULL);
 	if (ret != 0) {
