@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2010 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -27,6 +27,9 @@
 
 #include <schedwi.h>
 
+#if HAVE_SYS_SELECT_H
+#include <sys/select.h>
+#endif
 #if HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
@@ -41,17 +44,22 @@
 extern "C" {
 #endif
 
-extern int hostname_cmp OF((const char *h1, const char *h2));
-extern short int get_port_number OF((const char *port));
-extern int net_server OF((const char *port_number, const char *iface));
-extern int build_client_names_from_addr OF((struct in_addr in, char ***names));
-extern int build_client_names_from_name OF((	const char *host_name,
+extern int check_port OF((const char *port));
+extern int net_server OF((const char *port_number, const char *iface,
+			const char *address_family,
+			fd_set *sock_set, int *sock_max));
+extern int build_client_names_from_addr OF((const struct sockaddr_storage *in,
+						socklen_t inlen,
 						char ***names));
+extern int parse_hostname OF((const char *host_name, char **name, char **port));
+extern int build_client_names_from_name OF((	const char *host_name,
+						char ***names, char **port));
 extern void destroy_client_names OF((char **names));
 extern int net_client_sock OF((const char *port_number, const char *hostname));
-extern ssize_t net_read_sock OF((int sock, char **buff, unsigned int *len));
+extern ssize_t net_read_sock OF((int sock, char **buff, size_t *len));
 extern int net_write_sock OF((int sock, const char *buff, size_t len));
 extern int net_close_sock OF((int sock));
+extern void net_close_sock_set OF((fd_set *sock_set, int *sock_max));
 
 #ifdef __cplusplus
 }
