@@ -487,6 +487,8 @@ int
 net_init_server_ssl ()
 {
 	int ret;
+	unsigned int bits;
+
 
 	/* Build the Diffie Hellman parameters */
 	ret = gnutls_dh_params_init (&dh_params);
@@ -497,7 +499,13 @@ net_init_server_ssl ()
 		return -1;
 	}
 
-	ret = gnutls_dh_params_generate2 (dh_params, 1024);
+#if GNUTLS_VERSION_NUMBER >= 0x03010b
+	bits = gnutls_sec_param_to_pk_bits (	GNUTLS_PK_DH,
+						GNUTLS_SEC_PARAM_LEGACY);
+#else
+	bits = 1024;
+#endif
+	ret = gnutls_dh_params_generate2 (dh_params, bits);
 	if  (ret != 0) {
 		lwc_writeLog (	LOG_ERR,
 _("SSL: Failed to generate the parameters for the Diffie Hellman algorithms: %s"),
