@@ -85,7 +85,7 @@
  */
 static int
 copy_str (	char **dst, size_t *dst_len, int dst_idx,
-		const char *src, size_t src_len) 
+		const char *src, size_t src_len)
 {
 	char *tmp;
 	size_t l;
@@ -130,7 +130,7 @@ copy_str (	char **dst, size_t *dst_len, int dst_idx,
 static ssize_t
 parse_name (const char *param, size_t param_len)
 {
-	ssize_t i;
+	size_t i;
 
 #if HAVE_ASSERT_H
 	assert (param != NULL);
@@ -147,7 +147,7 @@ parse_name (const char *param, size_t param_len)
 	for (	i = 1;
 		i < param_len && (param[i] == '_' || isalnum (param[i]));
 		i++);
-	return i;
+	return (ssize_t)i;
 }
 
 
@@ -233,7 +233,7 @@ static ssize_t
 find_matching_bracket (const char *s, size_t len)
 {
 	int nb;
-	ssize_t i;
+	size_t i;
 
 #if HAVE_ASSERT_H
 	assert (s != NULL);
@@ -247,7 +247,7 @@ find_matching_bracket (const char *s, size_t len)
 		if (s[i] == '}') {
 			nb--;
 			if (nb == 0) {
-				return i;
+				return (ssize_t)i;
 			}
 		}
 	}
@@ -613,7 +613,7 @@ parse_key (const char *key, char **out, size_t *out_len)
  *      A=ABC                     -->      A=ABC
  *      B=A is $A                 -->      B=A is ABC
  *      C=C is ${D:-not set}      -->      C=C is not set
- *      D=\$D is $E               -->      D=$D is 
+ *      D=\$D is $E               -->      D=$D is
  *      E=foo                     -->      E=foo
  *
  * Return:
