@@ -54,17 +54,18 @@ extern int errno;
 #include <job_status.h>
 #include <startjob.h>
 #include <stopjob.h>
-#include <testfile.h>
 #include <lib_functions.h>
 #include <module.h>
 #include <schedwi_jobtree_priv.h>
+#include <check_waiting_can_start.h>
 
 #define TABSTOP 4
 
 /*
  * Error callback function for the sql_job_get_start_limit(),
  * sql_job_get_max_duration(), sql_job_get_retries(),
- * sql_job_get_retries_interval() and sql_status_get () functions
+ * sql_job_get_retries_interval(), sql_job_get_manual(),
+ * sql_job_get_manual_command() and sql_status_get () functions
  */
 static void
 sql_get_error_logger (void *data, const char *msg, int err_code)
@@ -93,77 +94,113 @@ set_schedwi_jobtree_node (	schedwi_jobtree_node_ptr ptr,
 				int job_time,
 				lwc_LL *hierarchy_list)
 {
-    short int time_limit;
-    int current_status;
-    long int start_time;
-    lwc_LL *rows;
-    row_item_t *row;
-    int n, i, j;
-    char *filename;
-    schedwi_jobtree_file_ptr constraint_files;
+	short int time_limit;
+	int current_status;
+	long int start_time;
+	lwc_LL *rows;
+	row_item_t *row;
+	int n, i, j;
+	char *manual_command;
+	char *filename;
+	schedwi_jobtree_file_ptr constraint_files;
 
 #if HAVE_ASSERT_H
-    assert (ptr != NULL && hierarchy_list != NULL);
+	assert (ptr != NULL && hierarchy_list != NULL);
 #endif
 
-    /* Retrieve parameters from the database */
-    if (sql_job_get_start_limit (workload_date, hierarchy_list, &time_limit,
-				sql_get_error_logger, NULL) != 0)
-    {
+	/* Retrieve parameters from the database */
+	if (sql_job_get_start_limit (	workload_date, hierarchy_list,
+					&time_limit,
+					sql_get_error_logger, NULL) != 0)
+	{
+		return -1;
+	}
+	ptr->start_limit = time_limit * 60; /* The limit in DB is in min */
+
+	if (sql_job_get_max_duration (	workload_date, hierarchy_list,
+					&time_limit,
+					sql_get_error_logger, NULL) != 0)
+	{
 	return -1;
-    }
-    ptr->start_limit = time_limit * 60; /* The limit in DB is in min */
+	}
+	ptr->max_duration = time_limit * 60; /* The limit in DB is in min */
 
-    if (sql_job_get_max_duration (workload_date, hierarchy_list, &time_limit,
+	if (sql_job_get_retries (	workload_date, hierarchy_list,
+					&(ptr->retries),
+					sql_get_error_logger, NULL) != 0)
+	{
+		return -1;
+	}
+
+	if (sql_job_get_retries_interval (	workload_date,
+						hierarchy_list,
+						&time_limit,
+						sql_get_error_logger,
+						NULL) != 0)
+	{
+		return -1;
+	}
+	ptr->retries_interval = time_limit * 60; /* The value in DB is in min */
+
+	if (sql_job_get_manual (workload_date, hierarchy_list, &(ptr->manual),
 				sql_get_error_logger, NULL) != 0)
-    {
-	return -1;
-    }
-    ptr->max_duration = time_limit * 60; /* The limit in DB is in min */
+	{
+		return -1;
+	}
+	if (ptr->manual == 0) {
+		if (ptr->manual_command != NULL) {
+			free (ptr->manual_command);
+		}
+		ptr->manual_command = NULL;
+	}
+	else {
+		if (sql_job_get_manual_command (workload_date, hierarchy_list,
+					&manual_command,
+					sql_get_error_logger, NULL) != 0)
+		{
+			return -1;
+		}
+		if (ptr->manual_command != NULL) {
+			free (ptr->manual_command);
+		}
+		ptr->manual_command = manual_command;
+	}
 
-    if (sql_job_get_retries (workload_date, hierarchy_list, &(ptr->retries),
-                             sql_get_error_logger, NULL) != 0)
-    {
-        return -1;
-    }
+	if (sql_status_get (	workload_date, ptr->id, &current_status,
+				&start_time, &(ptr->retry_num),
+				&(ptr->wait_reason), NULL,
+				sql_get_error_logger, NULL) != 0)
+	{
+		return -1;
+	}
 
-    if (sql_job_get_retries_interval (workload_date, hierarchy_list,
-                                      &time_limit,
-                                      sql_get_error_logger, NULL) != 0)
-    {
-        return -1;
-    }
-    ptr->retries_interval = time_limit * 60; /* The value in DB is in min */
-
-    if (sql_status_get (workload_date, ptr->id, &current_status, &start_time,
-                        &(ptr->retry_num), NULL,
-                        sql_get_error_logger, NULL) != 0)
-    {
-        return -1;
-    }
-
-    ptr->status = (current_status == 0)
-                ? JOB_STATUS_STATE_WAITING
-                : job_status_state_int2status (current_status);
-    if (current_status == 0) {
-        /* It's a new job (waiting). Add an entry in the job_status table */
-        job_status_set (ptr->id, ptr->path, workload_date,
-                        JOB_STATUS_STATE_WAITING, 0, 0, 0, NULL);
-    }
-    ptr->start_time = (ptr->status == JOB_STATUS_STATE_RUNNING)
-                                               ? (schedwi_time) start_time : 0;
-    ptr->run_time   = schedwi_time_convert (job_date, job_time);
+	ptr->status = (current_status == 0)
+			 	? JOB_STATUS_STATE_WAITING
+		  		: job_status_state_int2status (current_status);
+	if (current_status == 0) {
+		/*
+		 * It's a new job (waiting). Add an entry in the job_status
+		 * table
+		 */
+		ptr->wait_reason = WAIT_REASON_MASK_TIME;
+		job_status_set (ptr->id, ptr->path, workload_date,
+				JOB_STATUS_STATE_WAITING, 0, 0, 0,
+				ptr->wait_reason, NULL);
+	}
+	ptr->start_time = (ptr->status == JOB_STATUS_STATE_RUNNING)
+				? (schedwi_time) start_time : 0;
+	ptr->run_time   = schedwi_time_convert (job_date, job_time);
 
 
-    /* Retrieve contraint files*/
-    constraint_files = NULL;
-    j = 0;
-    if (sql_constraint_file_get (workload_date, &rows, ptr->id,
-                                 sql_get_error_logger, NULL) != 0)
-    {
-        return -1;
-    }
-    n = lwc_getNumNode (rows);
+	/* Retrieve contraint files*/
+	constraint_files = NULL;
+	j = 0;
+	if (sql_constraint_file_get (	workload_date, &rows, ptr->id,
+					sql_get_error_logger, NULL) != 0)
+	{
+		return -1;
+	}
+	n = lwc_getNumNode (rows);
     if (n != 0) {
         constraint_files = (schedwi_jobtree_file_ptr) malloc (
                                             sizeof (schedwi_jobtree_file) * n);
@@ -212,11 +249,11 @@ set_schedwi_jobtree_node (	schedwi_jobtree_node_ptr ptr,
 		}
 		free (ptr->constraint_files);
 	}
-    ptr->constraint_files = constraint_files;
-    ptr->num_constraint_files = j;
-    lwc_delLL (rows, (void (*)(const void *)) sql_free_row);
+	ptr->constraint_files = constraint_files;
+	ptr->num_constraint_files = j;
+	lwc_delLL (rows, (void (*)(const void *)) sql_free_row);
 
-    return 0;
+	return 0;
 }
 
 
@@ -261,6 +298,7 @@ new_schedwi_jobtree_node (	unsigned long long int id,
 	ptr->links_in   = NULL;
 	ptr->constraint_files = NULL;
 	ptr->num_constraint_files = 0;
+	ptr->manual_command = NULL;
 
 	if (set_schedwi_jobtree_node (	ptr, workload_date, job_date, job_time,
 					hierarchy_list) != 0)
@@ -301,6 +339,9 @@ free_schedwi_jobtree_node (schedwi_jobtree_node_ptr ptr)
 		if (ptr->path != NULL) {
 			free (ptr->path);
 		}
+		if (ptr->manual_command != NULL) {
+			free (ptr->manual_command);
+		}
 		if (ptr->constraint_files != NULL) {
 			i = ptr->num_constraint_files;
 			while (--i >= 0) {
@@ -359,7 +400,7 @@ update_jobtree_node (schedwi_jobtree_node_ptr ptr, int workload_date)
 	}
 
 	for (p = ptr; p != NULL; p = p->parent) {
-		if (lwc_addEndLL (hierarchy_list, (&ptr->id)) != 0) {
+		if (lwc_addEndLL (hierarchy_list, (&p->id)) != 0) {
 			lwc_delLL (hierarchy_list, NULL);
 			lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
 			return -1;
@@ -522,8 +563,8 @@ sql_list_error_logger (void *data, const char *msg, int err_code)
  *
  * Return:
  *   0 --> No error.  children contains the tree and must be freed by
- *         free_jobtree_all_nodes(). nb_jobs contains the number of
- *         jobs/jobsets in the returned tree.
+ *	   free_jobtree_all_nodes(). nb_jobs contains the number of
+ *	   jobs/jobsets in the returned tree.
  *  -1 --> Memory allocation error.  An error message has been logged by
  *	   using lwc_writeLog().
  *  -2 --> Database error.  An error message has been logged by
@@ -847,8 +888,8 @@ build_jobtree_recur (	schedwi_jobtree_node_ptr jobset,
  *
  * Return:
  *   0 --> No error.  top contains the tree and must be freed by
- *         free_jobtree_all_nodes(). nb_jobs contains the number of
- *         jobs/jobsets in the returned tree.
+ *	   free_jobtree_all_nodes(). nb_jobs contains the number of
+ *	   jobs/jobsets in the returned tree.
  *  -1 --> Memory allocation error.  An error message has been logged by
  *	   using lwc_writeLog().
  *  -2 --> Database error.  An error message has been logged by
@@ -1173,7 +1214,7 @@ static int schedwi_jobtree_node_set_status OF((	schedwi_date workload_date,
  * function starts the job on the remote client
  *
  * Return:
- *      0 --> No error
+ *	0 --> No error
  *  other --> Error. A message has been logged by lwc_writeLog()
  */
 static int
@@ -1198,9 +1239,10 @@ do_transition (	schedwi_date workload_date,
 						ptr->id, &reply);
 				if (ret != 0) {
 					/*
-					 * Failed to start the job or job
-					 * completed (if ret == 2)
+					 * Failed to start the job, or job
+					 * completed or detached (if ret == 2)
 					 */
+	  				ptr->wait_reason = 0;
 					ret = schedwi_jobtree_node_set_status (
 						workload_date,
 						ptr,
@@ -1224,6 +1266,7 @@ do_transition (	schedwi_date workload_date,
 				if (	   ptr->node_type == 0
 					&& ptr->children == NULL)
 				{
+	  				ptr->wait_reason = 0;
 					return schedwi_jobtree_node_set_status(
 						workload_date,
 						ptr,
@@ -1250,7 +1293,7 @@ do_transition (	schedwi_date workload_date,
  *   0 --> No error
  *  -1 --> Error.  An error message has been logged by using lwc_writeLog()
  *  -2 --> Database error.  An error message has been logged by using
- *         lwc_writeLog()
+ *	   lwc_writeLog()
  */
 static int
 schedwi_jobtree_node_set_status (	schedwi_date workload_date,
@@ -1293,6 +1336,7 @@ schedwi_jobtree_node_set_status (	schedwi_date workload_date,
 			(duration >= 0)	? duration
 					: current_time - ptr->start_time,
 			ptr->retry_num,
+			ptr->wait_reason,
 			status_message);
 	if (ret != 0) {
 		return ret;
@@ -1348,6 +1392,7 @@ schedwi_jobtree_node_set_status (	schedwi_date workload_date,
 
 	/* Update the parent jobset */
 	if (ptr->status == JOB_STATUS_STATE_RUNNING) {
+	  	ptr->wait_reason = 0;
 		ret =  schedwi_jobtree_node_set_status (
 						workload_date, ptr->parent,
 						JOB_STATUS_STATE_RUNNING,
@@ -1398,6 +1443,7 @@ schedwi_jobtree_node_set_status (	schedwi_date workload_date,
 					}
 				}
 				if (sibling == NULL) {
+	   				ptr->wait_reason = 0;
 					ret = schedwi_jobtree_node_set_status (
 							workload_date,
 							ptr->parent,
@@ -1421,7 +1467,7 @@ schedwi_jobtree_node_set_status (	schedwi_date workload_date,
  * Check if the provided job/jobset must be started
  *
  * Return:
- *      0 --> No error
+ *	0 --> No error
  *  other --> Error.  An error message has been logged by lwc_writeLog()
  */
 static int
@@ -1429,9 +1475,7 @@ schedwi_jobtree_node_check (	schedwi_date workload_date,
 				schedwi_jobtree_node_ptr ptr,
 				schedwi_time current_time)
 {
-	schedwi_jobtree_link_ptr link;
-	schedwi_time t;
-	int ret, i, d;
+	int ret, d;
 	char *reply;
 
 	if (ptr == NULL) {
@@ -1445,8 +1489,8 @@ schedwi_jobtree_node_check (	schedwi_date workload_date,
 
 		case JOB_STATUS_STATE_RUNNING:
 			/*
-			 * Be sure that the current job/jobset is not
-			 * running for too long
+			 * Be sure that the current job/jobset has not
+			 * run for too long
 			 */
 			if (	   ptr->max_duration > 0
 				&& schedwi_time_add_seconds (ptr->start_time,
@@ -1486,124 +1530,22 @@ schedwi_jobtree_node_check (	schedwi_date workload_date,
 			return 0;
 
 		case JOB_STATUS_STATE_WAITING:
-
-			/* Check that the parent is running */
-			if (	   ptr->parent != NULL
-				&& ptr->parent->status !=
-						JOB_STATUS_STATE_RUNNING)
-			{
-				/* The parent is not running */
-				return 0;
+			ret = check_waiting_can_start (d, ptr, current_time);
+			if (ret == 0) {
+				return schedwi_jobtree_node_set_status (
+						workload_date, ptr,
+						JOB_STATUS_STATE_RUNNING,
+						current_time, -1, 0,
+						NULL);
 			}
-
-			/* Check the start time*/
-			if (current_time < ptr->run_time) {
-				/* It's not time yet */
-				return 0;
-			}
-
-			/* Check if it is not to late to start the job */
-			if (ptr->start_limit > 0) {
-				if (ptr->run_time > 0) {
-					t = ptr->run_time;
-				}
-				else {
-					/* Parent start time */
-					if (ptr->parent == NULL) {
-						/*
-						 * Root jobset
-						 * Shouldn't be possible
-						 * (there is something wrong
-						 * in the database for the
-						 * definition of the root
-						 * jobset which shouldn't
-						 * have a start time limit)
-						 * The limit is then ignored
-						 * here
-						 */
-						t = current_time;
-					}
-					else {
-						t = ptr->parent->start_time;
-					}
-				}
-				if (current_time > schedwi_time_add_seconds (t,
-							ptr->start_limit))
-				{
-					/* Too late */
-					return schedwi_jobtree_node_set_status (
-						workload_date,
-						ptr,
+			if (ret == 2) {
+				return schedwi_jobtree_node_set_status (
+						workload_date, ptr,
 						JOB_STATUS_STATE_FAILED,
-						current_time,
-						0, 0,
+						current_time, 0, 0,
 						_("Start time limit reached"));
-				}
 			}
-
-			/* Check that all the links are okay */
-			for (	link = ptr->links;
-				   link != NULL
-				&& (link->linked_node->status ==
-							link->required_status
-					|| (link->required_status ==
-					JOB_STATUS_STATE_COMPLETED_OR_FAILED
-					   && (link->linked_node->status ==
-						JOB_STATUS_STATE_COMPLETED
-					       || link->linked_node->status ==
-						JOB_STATUS_STATE_FAILED)));
-				link = link->next);
-			if (link != NULL) {
-				/* Some links are not satisfied */
-				return 0;
-			}
-
-			/* Check the required files */
-if(ptr->constraint_files != NULL) {
-	for (i = 0; i < ptr->num_constraint_files; i++) {
-		reply = NULL;
-		ret = testfile (d, ptr->id,
-				(ptr->constraint_files)[i].host_id,
-				(ptr->constraint_files)[i].file,
-				&reply);
-		if (ret < 0) {
-			if (reply != NULL) {
-				free (reply);
-			}
-			return -1;
-		}
-		if (reply != NULL) {
-/* No need to log a message if the remote file is missing
-			if (reply[0] != '\0') {
-				lwc_writeLog (LOG_INFO,
-	_("Workload %d: %s (id %lld): Host Id %lld: check file %s: %s"),
-					d, ptr->path, ptr->id,
-					(ptr->constraint_files)[i].host_id,
-					(ptr->constraint_files)[i].file,
-					reply);
-			}
-*/
-			free (reply);
-		}
-		if (	   (ret == 0 &&  (ptr->constraint_files)[i].exist == 0)
-			|| (ret == 1 &&  (ptr->constraint_files)[i].exist != 0))
-		{
-			return 0;
-		}
-	}
-}
-
-			/* Call the `schedwi_check' function of the modules */
-			if (module_check (d, ptr) != 0) {
-				return 0;
-			}
-
-			/* Start the job/jobset */
-			return schedwi_jobtree_node_set_status (
-					workload_date,
-					ptr,
-					JOB_STATUS_STATE_RUNNING,
-					current_time, -1, 0, NULL);
+			return (ret < 0) ? ret: 0;
 
 		default:
 			return 0;
@@ -1652,7 +1594,7 @@ schedwi_jobtree_run (jobtree_ptr ptr, schedwi_time current_time)
  *   0 --> No error
  *  -1 --> Error.  An error message has been logged by using lwc_writeLog()
  *  -2 --> Database error.  An error message has been logged by using
- *         lwc_writeLog()
+ *	   lwc_writeLog()
  */
 int
 schedwi_jobtree_job_finished (	jobtree_ptr ptr,
@@ -1683,6 +1625,9 @@ schedwi_jobtree_job_finished (	jobtree_ptr ptr,
 	 * Change the status of the job (and do not check the
 	 * other jobs for now as the agent network connection is waiting)
 	 */
+	if (status != JOB_STATUS_STATE_WAITING) {
+		node_ptr->wait_reason = 0;
+	}
 	ret = schedwi_jobtree_node_set_status (	ptr->date,
 						node_ptr,
 						status,
@@ -1854,4 +1799,4 @@ schedwi_jobtree_adjust (jobtree_ptr ptr, int drift, schedwi_time current_time)
 	pthread_mutex_unlock (&(ptr->mutex));
 }
 
-/******************************** End Of File ********************************/
+/*-----------------============== End Of File ==============-----------------*/
