@@ -364,6 +364,9 @@ static char *job_tables[][3] = {
   { "job_file_err",	"file_err",		N_("error file names") },
   { "job_control_group", "control_group",	N_("Linux Control Group") },
   { "job_loadenv",	"loadenv",	N_("load user environment variables") },
+  { "job_detach",	"detach",	N_("start job in detach mode") },
+  { "job_command",	"command",	N_("manual job") },
+  { "job_manual_command", "manual_command", N_("manual job alert command") },
   { "job_success_return_code",	"success_ret",	N_("return codes") },
   { "job_command",	"command",		N_("remote commands") },
   { "job_arguments",	"argument",		N_("command parameters") },
