@@ -414,15 +414,22 @@ main (int argc, char **argv)
 		return 1;
 	}
 
+
 	/*
-	 * Change the group id and the user id of the process
+	 * Create the directory that will hold the PID file
 	 */
 	ret =  conf_get_param_string ("USER", &user_id);
 	ret += conf_get_param_string ("GROUP", &group_id);
+	ret += conf_get_param_string ("PID_FILE_REGISTRAR", &pid_file);
 #if HAVE_ASSERT_H
 	assert (ret == 0);
 #endif
 
+	mkpath (pid_file, user_id, group_id);
+
+	/*
+	 * Change the group id and the user id of the process
+	 */
 	ret = change_group (group_id);
 	if (ret != 0) {
 		if (ret == -2) {
@@ -618,10 +625,6 @@ main (int argc, char **argv)
 	 * Create the PID file and check that an other process is not already
 	 * running
 	 */
-	ret = conf_get_param_string ("PID_FILE_REGISTRAR", &pid_file);
-#if HAVE_ASSERT_H
-	assert (ret == 0);
-#endif
 	ret = write_pid_file (pid_file);
 	switch (ret) {
 		case -1:
