@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2011 Herve Quatremain
+   Copyright (C) 2007-2013 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -38,6 +38,10 @@
 #include <unistd.h>
 #endif
 
+#if HAVE_TIME_H
+#include <time.h>
+#endif
+
 #if HAVE_SYS_WAIT_H
 # include <sys/wait.h>
 #endif
@@ -382,7 +386,7 @@ start_net_server (struct socket_set *s_set)
 int
 main (int argc, char **argv)
 {
-	int ret, sig;
+	int ret, sig, fd;
 	const char *group_id, *user_id;
 	const char *log_file, *date_format;
 	const char *iface, *server_port, *address_family;
@@ -467,6 +471,11 @@ main (int argc, char **argv)
 		printf (_("Configuration file: %s\n"), configuration_file);
 	}
 
+	/*
+	 * seed for the rand() function that is used through the program
+	 */
+	srand ((unsigned int) time (NULL));
+
 	/*
 	 * Initialize the module engine
 	 */
@@ -500,13 +509,23 @@ main (int argc, char **argv)
 	ret += conf_get_param_bool ("SSLQuickRandom", &quick_random);
 	ret += conf_get_param_string ("USER", &user_id);
 	ret += conf_get_param_string ("GROUP", &group_id);
+	ret += conf_get_param_string ("PID_FILE", &pid_file);
 #if HAVE_ASSERT_H
 	assert (ret == 0);
 #endif
 
 	/*
 	 * Initialize the GnuTLS layer
+         *
+	 * The gnutls_global_init() function seems to open /dev/urandom.
+	 * To make *almost* sure that the file descriptor to be use is 3, we
+	 * start to close all the file descriptors above 2.  Later on, the
+	 * clean_process() function will close all the remaining file
+	 * descriptors, except 3.
 	 */
+	for (fd = getdtablesize () - 1; fd >= 3; fd--) {
+		close (fd);
+	}
 	if (net_init_gnutls (quick_random) != 0) {
 		conf_destroy_srv ();
 		module_exit ();
@@ -546,6 +565,11 @@ main (int argc, char **argv)
 		return 1;
 	}
 
+	/*
+	 * Create the directory that will hold the PID file
+	 */
+	mkpath (pid_file, user_id, group_id);
+
 	/*
 	 * Change the group id and the user id of the process
 	 */
@@ -656,10 +680,6 @@ main (int argc, char **argv)
 	 * Create the PID file and check that an other process is not already
 	 * running
 	 */
-	ret = conf_get_param_string ("PID_FILE", &pid_file);
-#if HAVE_ASSERT_H
-	assert (ret == 0);
-#endif
 	ret = write_pid_file (pid_file);
 	switch (ret) {
 		case -1:
