@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2010 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -31,55 +31,55 @@
 extern "C" {
 #endif
 
-extern unsigned int sql_cal_list OF((
+extern int sql_cal_list OF((
 			lwc_LL **rows,
-			void (*error_func)(void *, const char *, unsigned int),
+			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
-extern unsigned int sql_cal_only_list OF((
+extern int sql_cal_only_list OF((
 			int workload_date,
 			lwc_LL **rows,
-			void (*error_func)(void *, const char *, unsigned int),
+			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
-extern unsigned int sql_cal_get_main OF((const char *id,
+extern int sql_cal_get_main OF((const char *id,
 			lwc_LL **row,
-			void (*error_func)(void *, const char *, unsigned int),
+			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
-extern unsigned int sql_cal_get_details OF((const char *id,
-			void (*set_cal_id)(const char *, void *),
-			void (*set_cal_parent)(const char *, void *),
+extern int sql_cal_get_details OF((const char *id,
+			void (*set_cal_id)(unsigned long long int, void *),
+			void (*set_cal_parent)(unsigned long long int, void *),
 			void (*set_cal_name)(const char *, void *),
-			void (*set_cal_type)(const char *, void *),
+			void (*set_cal_type)(char, void *),
 			void (*set_cal_descr)(const char *, void *),
 			void (*set_cal_formula)(const char *, void *),
 			void *user_data_set_cal,
-			void (*error_func)(void *, const char *, unsigned int),
+			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
-extern unsigned int sql_cal_get_parent OF((const char *parent_id,
+extern int sql_cal_get_parent OF((const char *parent_id,
 			lwc_LL **rows,
-			void (*error_func)(void *, const char *, unsigned int),
+			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
 
-extern unsigned int sql_cal_update OF((const char *id,
+extern int sql_cal_update OF((const char *id,
 			const char *name,
 			const char *description,
 			const char *formula,
-			void (*error_func)(void *, const char *, unsigned int),
+			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
-extern unsigned int sql_cal_delete OF((char **cal_id_array,
+extern int sql_cal_delete OF((char **cal_id_array,
 			unsigned int len_array,
-			void (*error_func)(void *, const char *, unsigned int),
+			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
-extern unsigned int sql_cal_reparent OF((const char *parent_id,
+extern int sql_cal_reparent OF((const char *parent_id,
 			const char *id,
-			void (*error_func)(void *, const char *, unsigned int),
+			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
-extern unsigned int sql_cal_new OF((const char *name,
+extern int sql_cal_new OF((const char *name,
 			const char *parent_id,
 			const char *type,
 			const char *description,
 			const char *formula,
-			unsigned long int *new_env_id,
-			void (*error_func)(void *, const char *, unsigned int),
+			unsigned long long int *new_env_id,
+			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
 
 #ifdef __cplusplus
