@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2010 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -40,31 +40,31 @@
  * Get the links which source jobs/jobsets are in the provided list
  *
  * Return:
- *   0 --> No error.  rows contains the retrieved links and must be freed
- *         by the caller by
+ *     0 --> No error.  rows contains the retrieved links (row_item_t *) and
+ *           must be freed by the caller by
  *              lwc_delLL (rows, (void (*)(const void *)) sql_free_row);
- *     1 --> Memory allocation error (if error_func() is not NULL, it is called
+ *    -1 --> Memory allocation error (if error_func() is not NULL, it is called
  *           with user_data_error_func as its first parameter and the error
  *           message as the second parameter)
- * other --> SQL error (if error_func() is not NULL, it is called with
+ *    -2 --> SQL error (if error_func() is not NULL, it is called with
  *           user_data_error_func as its first parameter and the error message
  *           as the second parameter)
  */
-unsigned int
+int
 sql_link_get_list (	lwc_LL **rows,
 			int workload_date,
 			const char *id_list,
-			void (*error_func)(void *, const char *, unsigned int),
+			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func)
 {
 	char *err_msg = NULL;
-	unsigned int ret;
+	int ret;
 
 #if HAVE_ASSERT_H
 	assert (rows != NULL && id_list != NULL);
 #endif
 
-	ret = sql_select (	NULL, NULL, &err_msg, NULL, rows, NULL,
+	ret = sql_select (	NULL, NULL, &err_msg, NULL, rows,
 				SQL_LINK_LIST,
 				SQL_INT, (long int)workload_date,
 				SQL_STRING_NON_ESCAPE, id_list,
