@@ -42,12 +42,14 @@
 #include <sql_status.h>
 
 #define SQLSTATUS_WORKLOAD_LIST "SELECT DISTINCT workload_date FROM job_status ORDER BY workload_date"
-#define SQLSTATUS_GET "SELECT status,start_time,retry_num,error_msg FROM job_status WHERE workload_date=%d AND job_id=%ld"
-#define SQLSTATUS_UPDATE "UPDATE job_status SET status=%d,start_time=%u,retry_num=%d,error_msg=%s WHERE workload_date=%d AND job_id=%s"
-#define SQLSTATUS_SET "INSERT INTO job_status (workload_date,job_id,status,start_time,retry_num,error_msg) VALUES (%d,%s,%d,%u,%d,%s)"
+#define SQLSTATUS_GET "SELECT status,start_time,retry_num,wait_reason,error_msg FROM job_status WHERE workload_date=%d AND job_id=%ld"
+#define SQLSTATUS_UPDATE "UPDATE job_status SET status=%d,start_time=%u,retry_num=%d,wait_reason=%d,error_msg=%s WHERE workload_date=%d AND job_id=%s"
+#define SQLSTATUS_SET "INSERT INTO job_status (workload_date,job_id,status,start_time,retry_num,wait_reason,error_msg) VALUES (%d,%s,%d,%u,%d,%d,%s)"
+#define SQLSTATUS_UPDATE_WAIT_REASON "UPDATE job_status SET wait_reason=%d WHERE workload_date=%d AND job_id=%ld"
 #define SQLSTATUS_UPDATE_START_TIME "UPDATE job_status SET start_time=%u WHERE workload_date=%d AND job_id=%ld"
 #define SQLSTATUS_DEL "DELETE FROM job_status WHERE workload_date=%d"
 #define SQLSTATUS_DEL_TABLES "DELETE FROM %s_s WHERE workload_date=%d"
+#define SQLSTATUS_CLEAN_TABLES "DELETE FROM %s WHERE workload_date=%d"
 #define SQLSTATUS_COPY "INSERT INTO %s_s SELECT *,%d FROM %s"
 #define SQLSTATUS_GET_OLD "SELECT workload_date FROM %s_s WHERE workload_date<%d"
 
@@ -66,6 +68,9 @@ static char * status_tables[] = {	"calendars",
 					"job_file_err",
 					"job_control_group",
 					"job_loadenv",
+					"job_detach",
+					"job_manual",
+					"job_manual_command",
 					"job_success_return_code",
 					"job_command",
 					"job_arguments",
@@ -89,7 +94,12 @@ static char * status_tables[] = {	"calendars",
 					"link",
 					NULL
 				};
-
+/* Tables to clean at the same time as the job_status table */
+static char * to_clean_tables[] = {
+					"acknowledge_manual",
+					"commands",
+					NULL
+				};
 
 /*
  * Get all the available workload from the job_status database table
@@ -153,6 +163,7 @@ sql_status_get (int workload_date,
 		int *status,
 		long int *start_time,
 		int *retry_num,
+		int *wait_reason,
 		char **message,
 		void (*error_func)(void *, const char *, int),
 		void *user_data_error_func)
@@ -188,13 +199,13 @@ sql_status_get (int workload_date,
 	/* Message */
 	if (message != NULL) {
 		if (	   row == NULL
-			|| row[3].value_string == NULL
-			|| row[3].value_string[0] == '\0')
+			|| row[4].value_string == NULL
+			|| row[4].value_string[0] == '\0')
 		{
 			*message = NULL;
 		}
 		else {
-			s = (char *) malloc (row[3].len + 1);
+			s = (char *) malloc (row[4].len + 1);
 			if (s == NULL) {
 				sql_free_row (row);
 				lwc_delLL (rows,
@@ -206,7 +217,7 @@ sql_status_get (int workload_date,
 				}
 				return -1;
 			}
-			strcpy (s, row[3].value_string);
+			strcpy (s, row[4].value_string);
 			*message = s;
 		}
 	}
@@ -226,12 +237,74 @@ sql_status_get (int workload_date,
 				: (int)sql_row_item2ll (&(row[2]));
 	}
 
+	/* Why the job/jobset is waiting? */
+	if (wait_reason != NULL) {
+		*wait_reason = (row == NULL) ? 0
+				: (int)sql_row_item2ll (&(row[3]));
+	}
+
 	sql_free_row (row);
 	lwc_delLL (rows, (void (*)(const void *))sql_free_row);
 	return 0;
 }
 
 
+/*
+ * Change the reason why the given job/jobset is in the waiting state.
+ *
+ * @param workload_date:
+ * 			The workload date of the job/jobset.
+ * @param job_id:
+ * 			The database ID of the job or jobset.
+ * @param wait_reason:
+ * 			The reason why the job/jobset is waiting.  This is
+ * 			a bit mask of the flags defined in sql_status.h:
+ * 			WAIT_REASON_MASK_PARENT, WAIT_REASON_MASK_TIME, ...
+ * @param error_func:
+ * 			Caller error function which is called when an SQL
+ * 			error occurs.  May be NULL.
+ * @param user_data_error_func:
+ * 			Caller data which is passed to the error_func as the
+ * 			first parameter.
+ * @return:
+ *     0 --> Success
+ *    -1 --> Memory allocation error (if error_func() is not NULL, it is called
+ *           with user_data_error_func as its first parameter and the error
+ *           message as the second parameter)
+ *    -2 --> SQL error (if error_func() is not NULL, it is called with
+ *           user_data_error_func as its first parameter and the error message
+ *           as the second parameter)
+ */
+int
+sql_status_update_wait_reason (	int workload_date,
+				unsigned long long int job_id,
+				int wait_reason,
+				void (*error_func)(void *, const char *, int),
+				void *user_data_error_func)
+{
+	char *err_msg = NULL;
+	int ret;
+
+
+	ret = sql_non_select (  NULL, NULL, &err_msg, NULL, NULL, NULL,
+				SQLSTATUS_UPDATE_WAIT_REASON,
+				SQL_INT, (long int)wait_reason,
+				SQL_INT, (long int)workload_date,
+				SQL_INT, (long int)job_id,
+				SQL_END);
+	if (ret != 0) {
+		if (error_func != NULL) {
+			error_func (user_data_error_func, err_msg, ret);
+		}
+		if (err_msg != NULL) {
+			free (err_msg);
+		}
+		return ret;
+	}
+	return 0;
+}
+
+
 /*
  * Set the status of the provided job/jobset
  *
@@ -250,6 +323,7 @@ sql_status_set (int workload_date,
 		int status,
 		unsigned int start_time,
 		int retry_num,
+		int wait_reason,
 		const char *error_message,
 		void (*error_func)(void *, const char *, int),
 		void *user_data_error_func)
@@ -267,6 +341,7 @@ sql_status_set (int workload_date,
 				SQL_INT, (long int)status,
 				SQL_INT, (long int)start_time,
 				SQL_INT, (long int)retry_num,
+				SQL_INT, (long int)wait_reason,
 				SQL_STRING, (error_message != NULL)
 							? error_message: "",
 				SQL_INT, (long int)workload_date,
@@ -296,6 +371,7 @@ sql_status_set (int workload_date,
 				SQL_INT, (long int)status,
 				SQL_INT, (long int)start_time,
 				SQL_INT, (long int)retry_num,
+				SQL_INT, (long int)wait_reason,
 				SQL_STRING, (error_message != NULL)
 							? error_message: "",
 				SQL_END);
@@ -308,7 +384,6 @@ sql_status_set (int workload_date,
 		}
 		return ret;
 	}
-
 	return 0;
 }
 
@@ -399,9 +474,32 @@ sql_status_delete (int workload_date,
 		return ret;
 	}
 
+	/* Delete from the tables to clean */
+	err = 0;
+	for (i = 0; to_clean_tables[i] != NULL; i++);
+	do {
+		i--;
+		ret = sql_non_select (  &buff, &buff_len, &err_msg, NULL, NULL,
+					NULL,
+					SQLSTATUS_CLEAN_TABLES,
+					SQL_STRING_NON_ESCAPE,
+							to_clean_tables[i],
+					SQL_INT, (long int)workload_date,
+					SQL_END);
+		if (ret != 0) {
+			err = ret;
+			if (error_func != NULL) {
+				error_func (	user_data_error_func,
+						err_msg, ret);
+			}
+			if (err_msg != NULL) {
+				free (err_msg);
+			}
+		}
+	} while (i > 0);
+
 	/* And then delete the entries for all the other tables */
 	for (i = 0; status_tables[i] != NULL; i++);
-	err = 0;
 	do {
 		i--;
 		ret = sql_non_select (  &buff, &buff_len, &err_msg, NULL, NULL,
