@@ -120,8 +120,8 @@ argument_callback (void *obj, row_item_t *row)
  *         contains a reply message sent by the agent.  It may be NULL if the
  *         agent didn't send back a message.  out_message must be freed by
  *         the caller by free()
- *   2 --> The job does not have an associated command.  out_message is not
- *         changed
+ *   2 --> The job does not have an associated command or it's a detach job and
+ *         no need to wait for a result.  out_message is not changed
  *  -1 --> Error (a message is logged using lwc_writeLog()).  If not NULL,
  *         out_message contains an error message.  It may be NULL if there
  *         is not enought memory to allocate a buffer for this message.
@@ -136,6 +136,7 @@ startjob (	int workload_date, unsigned long long int job_id,
 	unsigned long long int host_id;
 	char *s, *err_msg = NULL;
 	int ret;
+	char detach;
 	startjob_request_ptr request;
 	row_item_t *host_details;
 	schedwi_BIO *b;
@@ -534,6 +535,66 @@ startjob (	int workload_date, unsigned long long int job_id,
 		}
 	}
 
+	/* Get the detach mode flag */
+	if (get_job_parameter (	workload_date, hierarchy_list,
+				"job_detach_s", "detach",
+				&value, &err_msg) != 0)
+	{
+		lwc_delLL (hierarchy_list, (void (*)(const void *))free);
+		startjob_request_destroy (request);
+		if (err_msg != NULL) {
+			lwc_writeLog (LOG_CRIT, err_msg);
+			if (out_message != NULL) {
+				*out_message = err_msg;
+			}
+			else {
+				free (err_msg);
+			}
+		}
+		else {
+			lwc_writeLog (LOG_CRIT,
+			_("Job %lld: cannot retrieve the `detach mode' flag"),
+				job_id);
+			if (out_message != NULL) {
+				err_msg =
+		_("Server error: cannot retrieve the `detach mode' flag");
+				*out_message = (char *)malloc (
+						schedwi_strlen (err_msg) + 1);
+				if (*out_message != NULL) {
+					strcpy (*out_message, err_msg);
+				}
+			}
+		}
+		return -1;
+	}
+
+	detach = 0;
+	if (value.type != RES_END) {
+		if (sql_row_item2ll(&value) == 0) {
+			s = "0";
+		}
+		else {
+			s = "1";
+			detach = 1;
+		}
+		s = (sql_row_item2ll(&value) == 0) ? "0" : "1";
+		if (startjob_request_add_detach (request, s, 1) != 0) {
+			lwc_delLL (	hierarchy_list,
+					(void (*)(const void *))free);
+			startjob_request_destroy (request);
+			if (out_message != NULL) {
+				err_msg =
+			_("Server error: cannot retrieve the `detach' flag");
+				*out_message = (char *)malloc (
+						schedwi_strlen (err_msg) + 1);
+				if (*out_message != NULL) {
+					strcpy (*out_message, err_msg);
+				}
+			}
+			return -1;
+		}
+	}
+
 	/* Get the command arguments */
 	ret = get_job_parameters_multi (workload_date, hierarchy_list,
 				"job_arguments_s", "position,argument",
@@ -629,6 +690,9 @@ _("Server error: cannot establish the connection with the remote agent");
 	/* Read the result */
 	ret = net_read_result (b, out_message);
 	net_close (b);
+	if (ret == 0 && detach == 1) {
+		return 2;
+	}
 	return ret;
 }
 
